/********************************************************************************
** Form generated from reading UI file 'edgeproperties.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDGEPROPERTIES_H
#define UI_EDGEPROPERTIES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EdgeProperties
{
public:
    QVBoxLayout *verticalLayout_3;
    QWidget *Appearance;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_3;
    QLabel *labelType;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QComboBox *type;
    QGroupBox *DynamicProperties;
    QGridLayout *gridLayout;
    QTableWidget *dynamicProperties;

    void setupUi(QWidget *EdgeProperties)
    {
        if (EdgeProperties->objectName().isEmpty())
            EdgeProperties->setObjectName("EdgeProperties");
        EdgeProperties->resize(325, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(EdgeProperties->sizePolicy().hasHeightForWidth());
        EdgeProperties->setSizePolicy(sizePolicy);
        EdgeProperties->setMinimumSize(QSize(0, 0));
        verticalLayout_3 = new QVBoxLayout(EdgeProperties);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        Appearance = new QWidget(EdgeProperties);
        Appearance->setObjectName("Appearance");
        verticalLayout_4 = new QVBoxLayout(Appearance);
        verticalLayout_4->setObjectName("verticalLayout_4");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        labelType = new QLabel(Appearance);
        labelType->setObjectName("labelType");
        sizePolicy.setHeightForWidth(labelType->sizePolicy().hasHeightForWidth());
        labelType->setSizePolicy(sizePolicy);
        labelType->setLayoutDirection(Qt::LeftToRight);
        labelType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(labelType, 0, 0, 1, 1);

        widget = new QWidget(Appearance);
        widget->setObjectName("widget");
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(4, 0, 0, 0);
        type = new QComboBox(widget);
        type->setObjectName("type");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(type->sizePolicy().hasHeightForWidth());
        type->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(type, 0, 1, 1, 1);


        gridLayout_3->addWidget(widget, 0, 1, 1, 1);


        verticalLayout_4->addLayout(gridLayout_3);


        verticalLayout_3->addWidget(Appearance);

        DynamicProperties = new QGroupBox(EdgeProperties);
        DynamicProperties->setObjectName("DynamicProperties");
        gridLayout = new QGridLayout(DynamicProperties);
        gridLayout->setObjectName("gridLayout");
        dynamicProperties = new QTableWidget(DynamicProperties);
        dynamicProperties->setObjectName("dynamicProperties");

        gridLayout->addWidget(dynamicProperties, 0, 0, 1, 1);


        verticalLayout_3->addWidget(DynamicProperties);


        retranslateUi(EdgeProperties);

        QMetaObject::connectSlotsByName(EdgeProperties);
    } // setupUi

    void retranslateUi(QWidget *EdgeProperties)
    {
        EdgeProperties->setWindowTitle(tr2i18n("Edge Properties", nullptr));
        labelType->setText(tr2i18n("Type:", nullptr));
        DynamicProperties->setTitle(tr2i18n("Dynamic Properties", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EdgeProperties: public Ui_EdgeProperties {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDGEPROPERTIES_H

