/****************************************************************************
** Meta object code from reading C++ file 'node.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/libgraphtheory/node.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'node.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory4NodeE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::Node::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory4NodeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::Node",
        "typeChanged",
        "",
        "NodeTypePtr",
        "type",
        "edgeAdded",
        "EdgePtr",
        "edge",
        "positionChanged",
        "QPointF",
        "position",
        "idChanged",
        "id",
        "colorChanged",
        "QColor",
        "color",
        "styleChanged",
        "dynamicPropertyAboutToBeAdded",
        "dynamicPropertyAdded",
        "dynamicPropertiesAboutToBeRemoved",
        "dynamicPropertyRemoved",
        "dynamicPropertyChanged",
        "index",
        "dynamicPropertiesChanged",
        "updateDynamicProperty",
        "property",
        "x",
        "y",
        "dynamicProperties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(NodeTypePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'edgeAdded'
        QtMocHelpers::SignalData<void(EdgePtr)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const QPointF &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicPropertyAboutToBeAdded'
        QtMocHelpers::SignalData<void(const QString &, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'dynamicPropertyAdded'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicPropertiesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'dynamicPropertyRemoved'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicPropertyChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Signal 'dynamicPropertiesChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateDynamicProperty'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(26, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(27, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'dynamicProperties'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Node, qt_meta_tag_ZN11GraphTheory4NodeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::Node::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4NodeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4NodeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory4NodeE_t>.metaTypes,
    nullptr
} };

void GraphTheory::Node::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Node *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<NodeTypePtr>>(_a[1]))); break;
        case 1: _t->edgeAdded((*reinterpret_cast<std::add_pointer_t<EdgePtr>>(_a[1]))); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 3: _t->idChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->styleChanged(); break;
        case 6: _t->dynamicPropertyAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->dynamicPropertyAdded(); break;
        case 8: _t->dynamicPropertiesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->dynamicPropertyRemoved(); break;
        case 10: _t->dynamicPropertyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->dynamicPropertiesChanged(); break;
        case 12: _t->updateDynamicProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Node::*)(NodeTypePtr )>(_a, &Node::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(EdgePtr )>(_a, &Node::edgeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(const QPointF & )>(_a, &Node::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(int )>(_a, &Node::idChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(const QColor & )>(_a, &Node::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)()>(_a, &Node::styleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(const QString & , int )>(_a, &Node::dynamicPropertyAboutToBeAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)()>(_a, &Node::dynamicPropertyAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(int , int )>(_a, &Node::dynamicPropertiesAboutToBeRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)()>(_a, &Node::dynamicPropertyRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)(int )>(_a, &Node::dynamicPropertyChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Node::*)()>(_a, &Node::dynamicPropertiesChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->dynamicProperties(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setX(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setY(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GraphTheory::Node::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::Node::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4NodeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::Node::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void GraphTheory::Node::typeChanged(NodeTypePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void GraphTheory::Node::edgeAdded(EdgePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void GraphTheory::Node::positionChanged(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void GraphTheory::Node::idChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void GraphTheory::Node::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void GraphTheory::Node::styleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GraphTheory::Node::dynamicPropertyAboutToBeAdded(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void GraphTheory::Node::dynamicPropertyAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GraphTheory::Node::dynamicPropertiesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void GraphTheory::Node::dynamicPropertyRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void GraphTheory::Node::dynamicPropertyChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void GraphTheory::Node::dynamicPropertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
