// /org/kde/rocs/GraphSelectionRectangle.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qhash.h>
#include <QtCore/qalgorithms.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qrandom.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <cmath>
#include <limits>
#include <type_traits>

namespace QmlCacheGeneratedCode {
namespace _org_kde_rocs_GraphSelectionRectangle_qml {
QQmlPrivate::AOTLookupValidation::LookupSignatures expectedLookupSignatures()
{
    using namespace Qt::StringLiterals;
    using namespace QQmlPrivate::AOTLookupValidation;
    return {
        { Lookup{ Type{ u""_s, u"QQmlPointFValueType"_s, u""_s, IsComposite::No, IsIC::No }, u"x"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
        { Lookup{ Type{ u""_s, u"QQmlPointFValueType"_s, u""_s, IsComposite::No, IsIC::No }, u"y"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 1 } },
    };
}

bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu)
{
    enum ValidationState { Pending, Failed, Succeeded };
    static ValidationState state = Pending;
    if (state == Failed)
        return false;
    if (state == Succeeded)
        return true;
    const auto &expectedSignatures = expectedLookupSignatures();
    for (const auto &[lookup, expectedSignature] : expectedSignatures.asKeyValueRange()) {
        if (!QQmlPrivate::AOTLookupValidation::validateLookupSignature(engine, cu, lookup, expectedSignature)) {
            state = Failed;
            return false;
        }
    }
    state = Succeeded;
    return true;
}

extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0xa,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x6d,0xad,0xbc,
0xb,0xbd,0x9f,0x36,0xb6,0x34,0x41,0x8b,
0x1e,0xdd,0xa0,0x7b,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0xe0,0x4,0x0,0x0,
0x7,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xc0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc8,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x8,0x0,0x0,
0xc8,0x1,0x0,0x0,0x30,0x2,0x0,0x0,
0x98,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x68,0x3,0x0,0x0,0x0,0x4,0x0,0x0,
0x60,0x4,0x0,0x0,0xc0,0x4,0x0,0x0,
0xd0,0x4,0x0,0x0,0x83,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x94,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x80,0x0,0x0,0x0,
0x94,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0xa4,0x1,0x0,0x0,0x83,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x80,0x0,0x0,0x0,
0xa4,0x1,0x0,0x0,0x33,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x27,0x1,0x0,0x0,
0x27,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x3f,
0x44,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0xc,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x18,0x7,
0x2e,0x1,0x3c,0x2,0x3c,0x3,0x18,0xa,
0x2e,0x4,0x3c,0x5,0x3c,0x6,0x18,0xb,
0xac,0x7,0x7,0x2,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x18,0x7,
0x2e,0x9,0x3c,0xa,0x3c,0xb,0x18,0xa,
0x2e,0xc,0x3c,0xd,0x3c,0xe,0x18,0xb,
0xac,0xf,0x7,0x2,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x10,0x18,0x7,
0x2e,0x11,0x3c,0x12,0x3c,0x13,0x18,0xb,
0x2e,0x14,0x3c,0x15,0x3c,0x16,0xa2,0xb,
0x18,0xa,0xac,0x17,0x7,0x1,0xa,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0xf,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x18,0x18,0x7,
0x2e,0x19,0x3c,0x1a,0x3c,0x1b,0x18,0xb,
0x2e,0x1c,0x3c,0x1d,0x3c,0x1e,0xa2,0xb,
0x18,0xa,0xac,0x1f,0x7,0x1,0xa,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x3b,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x2,0x0,0x2,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xf,0x0,0x0,0x0,
0x17,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1a,0x6,0x9,0x2e,
0x20,0x3c,0x21,0x66,0x9,0x50,0x11,0x1a,
0x6,0xa,0x2e,0x22,0x3c,0x23,0x18,0xb,
0x2e,0x24,0x3c,0x25,0x80,0xb,0x6a,0xa,
0x50,0x9,0x1a,0x7,0xc,0x2e,0x26,0x3c,
0x27,0x66,0xc,0x50,0x11,0x1a,0x7,0xd,
0x2e,0x28,0x3c,0x29,0x18,0xe,0x2e,0x2a,
0x3c,0x2b,0x80,0xe,0x6a,0xd,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x1c,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0xb4,0x2c,0x0,0x0,0x18,0x6,0xd4,
0x16,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x1d,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0xb4,0x2d,0x0,0x0,0x18,0x6,0xd4,
0x16,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x5,0x0,0x0,0x58,0x5,0x0,0x0,
0x70,0x5,0x0,0x0,0x88,0x5,0x0,0x0,
0x98,0x5,0x0,0x0,0xa8,0x5,0x0,0x0,
0xb8,0x5,0x0,0x0,0xc0,0x5,0x0,0x0,
0xe8,0x5,0x0,0x0,0xf0,0x5,0x0,0x0,
0x18,0x6,0x0,0x0,0x28,0x6,0x0,0x0,
0x58,0x6,0x0,0x0,0x70,0x6,0x0,0x0,
0xa0,0x6,0x0,0x0,0xb0,0x6,0x0,0x0,
0xc8,0x6,0x0,0x0,0xe0,0x6,0x0,0x0,
0xf8,0x6,0x0,0x0,0x10,0x7,0x0,0x0,
0x28,0x7,0x0,0x0,0x48,0x7,0x0,0x0,
0x88,0x7,0x0,0x0,0xa8,0x7,0x0,0x0,
0xe8,0x7,0x0,0x0,0xf8,0x7,0x0,0x0,
0x8,0x8,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x52,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x72,0x0,
0x6f,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x78,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x79,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x77,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x68,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x23,0x0,0x61,0x0,
0x66,0x0,0x63,0x0,0x33,0x0,0x64,0x0,
0x65,0x0,0x66,0x0,0x66,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x72,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x65,0x0,0x65,0x0,0x6c,0x0,0x62,0x0,
0x6c,0x0,0x75,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x63,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x69,0x0,
0x6e,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x46,0x0,0x72,0x0,0x6f,0x0,0x6d,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x46,0x0,
0x72,0x0,0x6f,0x0,0x6d,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x54,0x0,0x6f,0x0,0x43,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x54,0x0,
0x6f,0x0,0x43,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x6d,0x0,0x69,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x2c,0x0,0x0,0x0,
0x74,0x1,0x0,0x0,0x2,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x1,0x0,0x2,0x0,
0x54,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x70,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x1,0x0,0x8,0x0,0x74,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x34,0x1,0x0,0x0,
0x6,0x0,0x10,0x0,0x7,0x0,0x50,0x0,
0x34,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x34,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0xc,0x0,0x0,0x20,0x9,0x0,0x50,0x0,
0x5,0x0,0x0,0x0,0xc,0x0,0x0,0x20,
0xa,0x0,0x50,0x0,0x34,0x1,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x50,0x0,0x1d,0x0,0x20,0x1,
0x14,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1c,0x0,0x50,0x0,0x1c,0x0,0x40,0x1,
0xe,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x11,0x0,0x50,0x0,0x11,0x0,0xc0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x50,0x0,0xf,0x0,0xd0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0xe,0x0,0xc0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0xd,0x0,0x80,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x50,0x0,0xc,0x0,0x80,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x12,0x0,0xc0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0xc0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0xc0,0x0,0x13,0x0,0x30,0x1,
0xe,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x12,0x0,0xc0,0x0,0x12,0x0,0x30,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for x at line 12, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_14;
QVariant v2_6;
double v2_16_v11_18;
double v2_20;
double v2_8_v10_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(1, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
s.v2_6 = QVariant(aotContext->lookupResultMetaType(2));
while (!aotContext->getObjectLookup(2, s.v2_4, s.v2_6.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(2, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_6 = QVariant(aotContext->lookupResultMetaType(2));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getValueLookup(3, s.v2_6.data(), &s.v2_8_v10_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetValueLookup(3, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(4, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
s.v2_14 = QVariant(aotContext->lookupResultMetaType(5));
while (!aotContext->getObjectLookup(5, s.v2_12, s.v2_14.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(5, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_14 = QVariant(aotContext->lookupResultMetaType(5));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getValueLookup(6, s.v2_14.data(), &s.v2_16_v11_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetValueLookup(6, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_8_v10_10;
const double arg2 = s.v2_16_v11_18;
s.v2_20 = [&]() { 
auto  tmpMin = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == -1) ? arg2 : ((arg2 < arg1 || std::isnan(arg2)) ? arg2 : arg1);
return tmpMin;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_20;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for y at line 13, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_14;
QVariant v2_6;
double v2_16_v11_18;
double v2_20;
double v2_8_v10_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(9, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(9);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
s.v2_6 = QVariant(aotContext->lookupResultMetaType(10));
while (!aotContext->getObjectLookup(10, s.v2_4, s.v2_6.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(10, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_6 = QVariant(aotContext->lookupResultMetaType(10));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getValueLookup(11, s.v2_6.data(), &s.v2_8_v10_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetValueLookup(11, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(12, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
s.v2_14 = QVariant(aotContext->lookupResultMetaType(13));
while (!aotContext->getObjectLookup(13, s.v2_12, s.v2_14.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(13, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_14 = QVariant(aotContext->lookupResultMetaType(13));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getValueLookup(14, s.v2_14.data(), &s.v2_16_v11_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetValueLookup(14, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_8_v10_10;
const double arg2 = s.v2_16_v11_18;
s.v2_20 = [&]() { 
auto  tmpMin = (qIsNull(arg2) && qIsNull(arg1) && std::copysign(1.0, arg2) == -1) ? arg2 : ((arg2 < arg1 || std::isnan(arg2)) ? arg2 : arg1);
return tmpMin;
}();
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_20;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for width at line 14, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_14;
QVariant v2_6;
double v2_16;
double v2_18_v10_20;
double v2_22;
double v2_8_v11_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(17, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(17);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
s.v2_6 = QVariant(aotContext->lookupResultMetaType(18));
while (!aotContext->getObjectLookup(18, s.v2_4, s.v2_6.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(18, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_6 = QVariant(aotContext->lookupResultMetaType(18));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getValueLookup(19, s.v2_6.data(), &s.v2_8_v11_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetValueLookup(19, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(20, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(20);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
s.v2_14 = QVariant(aotContext->lookupResultMetaType(21));
while (!aotContext->getObjectLookup(21, s.v2_12, s.v2_14.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(21, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_14 = QVariant(aotContext->lookupResultMetaType(21));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getValueLookup(22, s.v2_14.data(), &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetValueLookup(22, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_18_v10_20 = (s.v2_8_v11_10 - s.v2_16);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_18_v10_20;
s.v2_22 = (qIsNull(arg1) ? 0 : (arg1 < 0.0 ? -arg1 : arg1));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_22;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for height at line 15, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_12 = nullptr;
QObject *v2_4 = nullptr;
QVariant v2_14;
QVariant v2_6;
double v2_16;
double v2_18_v10_20;
double v2_22;
double v2_8_v11_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(25, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
s.v2_6 = QVariant(aotContext->lookupResultMetaType(26));
while (!aotContext->getObjectLookup(26, s.v2_4, s.v2_6.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(26, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_6 = QVariant(aotContext->lookupResultMetaType(26));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getValueLookup(27, s.v2_6.data(), &s.v2_8_v11_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetValueLookup(27, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(28, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
s.v2_14 = QVariant(aotContext->lookupResultMetaType(29));
while (!aotContext->getObjectLookup(29, s.v2_12, s.v2_14.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(29, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_14 = QVariant(aotContext->lookupResultMetaType(29));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getValueLookup(30, s.v2_14.data(), &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetValueLookup(30, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_18_v10_20 = (s.v2_8_v11_10 - s.v2_16);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v2_18_v10_20;
s.v2_22 = (qIsNull(arg1) ? 0 : (arg1 < 0.0 ? -arg1 : arg1));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_22;
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onFromChanged at line 28, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_CallQmlContextPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr};
    return aotContext->callQmlContextPropertyLookup(44, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(44, -1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onToChanged at line 29, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_CallQmlContextPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr};
    return aotContext->callQmlContextPropertyLookup(45, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(45, -1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
