/****************************************************************************
** Meta object code from reading C++ file 'nodewrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/libgraphtheory/kernel/nodewrapper.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nodewrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::NodeWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::NodeWrapper",
        "message",
        "",
        "messageString",
        "GraphTheory::MessageType",
        "type",
        "idChanged",
        "id",
        "positionChanged",
        "QPointF",
        "position",
        "colorChanged",
        "QColor",
        "color",
        "typeChanged",
        "updateDynamicProperties",
        "edges",
        "QList<GraphTheory::EdgeWrapper*>",
        "inEdges",
        "outEdges",
        "neighbors",
        "QList<GraphTheory::NodeWrapper*>",
        "predecessors",
        "successors",
        "distance",
        "QJSValue",
        "lengthProperty",
        "targets",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'message'
        QtMocHelpers::SignalData<void(const QString &, GraphTheory::MessageType) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const QPointF &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateDynamicProperties'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'edges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>() const>(16, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Method 'edges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>(int) const>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'inEdges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>() const>(18, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Method 'inEdges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>(int) const>(18, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'outEdges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>() const>(19, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Method 'outEdges'
        QtMocHelpers::MethodData<QList<GraphTheory::EdgeWrapper*>(int) const>(19, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'neighbors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>() const>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Method 'neighbors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>(int) const>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'predecessors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>() const>(22, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Method 'predecessors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>(int) const>(22, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'successors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>() const>(23, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Method 'successors'
        QtMocHelpers::MethodData<QList<GraphTheory::NodeWrapper*>(int) const>(23, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'distance'
        QtMocHelpers::MethodData<QJSValue(const QString &, QList<GraphTheory::NodeWrapper*>)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 26 }, { 0x80000000 | 21, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(29, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'color'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'type'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NodeWrapper, qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::NodeWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>.metaTypes,
    nullptr
} };

void GraphTheory::NodeWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NodeWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GraphTheory::MessageType>>(_a[2]))); break;
        case 1: _t->idChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 3: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->typeChanged(); break;
        case 5: _t->updateDynamicProperties(); break;
        case 6: { QList<GraphTheory::EdgeWrapper*> _r = _t->edges();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<GraphTheory::EdgeWrapper*> _r = _t->edges((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QList<GraphTheory::EdgeWrapper*> _r = _t->inEdges();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QList<GraphTheory::EdgeWrapper*> _r = _t->inEdges((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QList<GraphTheory::EdgeWrapper*> _r = _t->outEdges();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QList<GraphTheory::EdgeWrapper*> _r = _t->outEdges((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::EdgeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QList<GraphTheory::NodeWrapper*> _r = _t->neighbors();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QList<GraphTheory::NodeWrapper*> _r = _t->neighbors((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QList<GraphTheory::NodeWrapper*> _r = _t->predecessors();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QList<GraphTheory::NodeWrapper*> _r = _t->predecessors((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QList<GraphTheory::NodeWrapper*> _r = _t->successors();
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QList<GraphTheory::NodeWrapper*> _r = _t->successors((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<GraphTheory::NodeWrapper*>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QJSValue _r = _t->distance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<GraphTheory::NodeWrapper*>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GraphTheory::NodeWrapper*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NodeWrapper::*)(const QString & , GraphTheory::MessageType ) const>(_a, &NodeWrapper::message, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NodeWrapper::*)(int )>(_a, &NodeWrapper::idChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NodeWrapper::*)(const QPointF & )>(_a, &NodeWrapper::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NodeWrapper::*)(const QColor & )>(_a, &NodeWrapper::colorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NodeWrapper::*)()>(_a, &NodeWrapper::typeChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->type(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setX(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setY(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setType(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GraphTheory::NodeWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::NodeWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory11NodeWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::NodeWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void GraphTheory::NodeWrapper::message(const QString & _t1, GraphTheory::MessageType _t2)const
{
    QMetaObject::activate<void>(const_cast< GraphTheory::NodeWrapper *>(this), &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void GraphTheory::NodeWrapper::idChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void GraphTheory::NodeWrapper::positionChanged(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void GraphTheory::NodeWrapper::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void GraphTheory::NodeWrapper::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
