/****************************************************************************
** Meta object code from reading C++ file 'graphdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/libgraphtheory/graphdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'graphdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::GraphDocument::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::GraphDocument",
        "nodeAboutToBeAdded",
        "",
        "NodePtr",
        "nodeAdded",
        "nodesAboutToBeRemoved",
        "nodesRemoved",
        "edgeAboutToBeAdded",
        "EdgePtr",
        "edgeAdded",
        "edgesAboutToBeRemoved",
        "edgesRemoved",
        "nodeTypeAboutToBeAdded",
        "NodeTypePtr",
        "nodeTypeAdded",
        "nodeTypesAboutToBeRemoved",
        "nodeTypesRemoved",
        "edgeTypeAboutToBeAdded",
        "EdgeTypePtr",
        "edgeTypeAdded",
        "edgeTypesAboutToBeRemoved",
        "edgeTypesRemoved",
        "documentNameChanged",
        "documentUrlChanged",
        "modifiedChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nodeAboutToBeAdded'
        QtMocHelpers::SignalData<void(NodePtr, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'nodeAdded'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nodesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'nodesRemoved'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgeAboutToBeAdded'
        QtMocHelpers::SignalData<void(EdgePtr, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'edgeAdded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'edgesRemoved'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nodeTypeAboutToBeAdded'
        QtMocHelpers::SignalData<void(NodeTypePtr, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'nodeTypeAdded'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nodeTypesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'nodeTypesRemoved'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgeTypeAboutToBeAdded'
        QtMocHelpers::SignalData<void(EdgeTypePtr, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'edgeTypeAdded'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgeTypesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'edgeTypesRemoved'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'documentUrlChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GraphDocument, qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::GraphDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>.metaTypes,
    nullptr
} };

void GraphTheory::GraphDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GraphDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nodeAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<NodePtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->nodeAdded(); break;
        case 2: _t->nodesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->nodesRemoved(); break;
        case 4: _t->edgeAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<EdgePtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->edgeAdded(); break;
        case 6: _t->edgesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->edgesRemoved(); break;
        case 8: _t->nodeTypeAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<NodeTypePtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->nodeTypeAdded(); break;
        case 10: _t->nodeTypesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->nodeTypesRemoved(); break;
        case 12: _t->edgeTypeAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<EdgeTypePtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->edgeTypeAdded(); break;
        case 14: _t->edgeTypesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->edgeTypesRemoved(); break;
        case 16: _t->documentNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->documentUrlChanged(); break;
        case 18: _t->modifiedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(NodePtr , int )>(_a, &GraphDocument::nodeAboutToBeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::nodeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(int , int )>(_a, &GraphDocument::nodesAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::nodesRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(EdgePtr , int )>(_a, &GraphDocument::edgeAboutToBeAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::edgeAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(int , int )>(_a, &GraphDocument::edgesAboutToBeRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::edgesRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(NodeTypePtr , int )>(_a, &GraphDocument::nodeTypeAboutToBeAdded, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::nodeTypeAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(int , int )>(_a, &GraphDocument::nodeTypesAboutToBeRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::nodeTypesRemoved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(EdgeTypePtr , int )>(_a, &GraphDocument::edgeTypeAboutToBeAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::edgeTypeAdded, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(int , int )>(_a, &GraphDocument::edgeTypesAboutToBeRemoved, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::edgeTypesRemoved, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)(const QString & )>(_a, &GraphDocument::documentNameChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::documentUrlChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphDocument::*)()>(_a, &GraphDocument::modifiedChanged, 18))
            return;
    }
}

const QMetaObject *GraphTheory::GraphDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::GraphDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory13GraphDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::GraphDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void GraphTheory::GraphDocument::nodeAboutToBeAdded(NodePtr _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void GraphTheory::GraphDocument::nodeAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GraphTheory::GraphDocument::nodesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void GraphTheory::GraphDocument::nodesRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GraphTheory::GraphDocument::edgeAboutToBeAdded(EdgePtr _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void GraphTheory::GraphDocument::edgeAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GraphTheory::GraphDocument::edgesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void GraphTheory::GraphDocument::edgesRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GraphTheory::GraphDocument::nodeTypeAboutToBeAdded(NodeTypePtr _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void GraphTheory::GraphDocument::nodeTypeAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void GraphTheory::GraphDocument::nodeTypesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void GraphTheory::GraphDocument::nodeTypesRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void GraphTheory::GraphDocument::edgeTypeAboutToBeAdded(EdgeTypePtr _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void GraphTheory::GraphDocument::edgeTypeAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void GraphTheory::GraphDocument::edgeTypesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void GraphTheory::GraphDocument::edgeTypesRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void GraphTheory::GraphDocument::documentNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void GraphTheory::GraphDocument::documentUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void GraphTheory::GraphDocument::modifiedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
