/****************************************************************************
** Meta object code from reading C++ file 'edge.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/libgraphtheory/edge.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'edge.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory4EdgeE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::Edge::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory4EdgeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::Edge",
        "typeChanged",
        "",
        "EdgeTypePtr",
        "type",
        "directionChanged",
        "EdgeType::Direction",
        "direction",
        "dynamicPropertyAboutToBeAdded",
        "dynamicPropertyAdded",
        "dynamicPropertiesAboutToBeRemoved",
        "dynamicPropertyRemoved",
        "dynamicPropertyChanged",
        "index",
        "dynamicPropertiesChanged",
        "styleChanged",
        "updateDynamicProperty",
        "property",
        "dynamicProperties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(EdgeTypePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'directionChanged'
        QtMocHelpers::SignalData<void(EdgeType::Direction)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'dynamicPropertyAboutToBeAdded'
        QtMocHelpers::SignalData<void(const QString &, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'dynamicPropertyAdded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicPropertiesAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'dynamicPropertyRemoved'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicPropertyChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'dynamicPropertiesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateDynamicProperty'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dynamicProperties'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Edge, qt_meta_tag_ZN11GraphTheory4EdgeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::Edge::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4EdgeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4EdgeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory4EdgeE_t>.metaTypes,
    nullptr
} };

void GraphTheory::Edge::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Edge *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<EdgeTypePtr>>(_a[1]))); break;
        case 1: _t->directionChanged((*reinterpret_cast<std::add_pointer_t<EdgeType::Direction>>(_a[1]))); break;
        case 2: _t->dynamicPropertyAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->dynamicPropertyAdded(); break;
        case 4: _t->dynamicPropertiesAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->dynamicPropertyRemoved(); break;
        case 6: _t->dynamicPropertyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->dynamicPropertiesChanged(); break;
        case 8: _t->styleChanged(); break;
        case 9: _t->updateDynamicProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Edge::*)(EdgeTypePtr )>(_a, &Edge::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)(EdgeType::Direction )>(_a, &Edge::directionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)(const QString & , int )>(_a, &Edge::dynamicPropertyAboutToBeAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)()>(_a, &Edge::dynamicPropertyAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)(int , int )>(_a, &Edge::dynamicPropertiesAboutToBeRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)()>(_a, &Edge::dynamicPropertyRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)(int )>(_a, &Edge::dynamicPropertyChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)()>(_a, &Edge::dynamicPropertiesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Edge::*)()>(_a, &Edge::styleChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->dynamicProperties(); break;
        default: break;
        }
    }
}

const QMetaObject *GraphTheory::Edge::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::Edge::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory4EdgeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::Edge::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void GraphTheory::Edge::typeChanged(EdgeTypePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void GraphTheory::Edge::directionChanged(EdgeType::Direction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void GraphTheory::Edge::dynamicPropertyAboutToBeAdded(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void GraphTheory::Edge::dynamicPropertyAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GraphTheory::Edge::dynamicPropertiesAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void GraphTheory::Edge::dynamicPropertyRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GraphTheory::Edge::dynamicPropertyChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void GraphTheory::Edge::dynamicPropertiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GraphTheory::Edge::styleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
