/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // rocsui.rc
  0x0,0x0,0x2,0x31,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x26,0x8,0x3d,0x11,0x0,0xc6,0x56,0x45,0x1e,0x40,0x73,0x1e,
  0x75,0x6d,0x2e,0x18,0x31,0xab,0xc6,0xfd,0x61,0xab,0xde,0x33,0xae,0x98,0x73,0xae,
  0x9e,0x96,0xf,0x5a,0x27,0x43,0x74,0x15,0x30,0x4,0x22,0x3e,0x0,0x3e,0x0,0x3a,
  0x0,0xef,0x46,0xcb,0x91,0xf2,0xdf,0x27,0x6d,0xd,0x74,0xdc,0x4,0x2c,0xcb,0x7a,
  0xef,0x40,0xfd,0x4b,0xd,0x71,0xe9,0x80,0x3d,0xed,0xc2,0x6a,0x1b,0xa2,0x27,0xa6,
  0xcc,0x2b,0x9,0x3d,0x51,0xa2,0x19,0x9c,0x83,0x52,0x69,0x8,0x49,0x3d,0x56,0x48,
  0x9b,0x35,0x41,0x60,0xd0,0x10,0xb4,0xfa,0xb5,0xcd,0x61,0x73,0xba,0x12,0x50,0x93,
  0xa7,0xd,0xdb,0xd2,0xa6,0xea,0x63,0xed,0x61,0x6b,0xaa,0xa5,0x9c,0xd5,0x14,0x2a,
  0x58,0xeb,0xe9,0x99,0xc8,0xf2,0xa2,0xa2,0x1d,0x81,0x9e,0x88,0xb5,0x78,0xaf,0x0,
  0x7b,0x9e,0x61,0x85,0xdc,0x83,0xdf,0x86,0xd4,0x1d,0x4f,0x2d,0xc1,0x9,0x24,0x62,
  0x79,0x3,0x81,0x80,0x50,0xb0,0xfc,0x5e,0x87,0xe7,0x95,0xdc,0x4,0xef,0xb1,0x11,
  0xfb,0x61,0xcf,0xbe,0x3d,0xdd,0x71,0x99,0xfc,0x21,0x51,0x6c,0xe5,0xdb,0x4a,0x5d,
  0x1d,0x23,0xd3,0x9e,0x2a,0x58,0x19,0x6c,0xd2,0x9e,0x72,0xb,0xef,0xf7,0x83,0x24,
  0xd1,0x5f,0xfd,0xef,0x89,0x9c,0x63,0x92,0xb2,0x4,0x99,0x73,0x0,0xe8,0xb2,0x6b,
  0xe,0x5f,0x5b,0x9f,0x2d,0x53,0x1d,0xcf,0x13,0x79,0x25,0x1f,0x74,0xa9,0xcb,0x6a,
  0x52,0x97,0xff,0xeb,0x90,0x3b,0x6b,0xa5,0x3c,0xe6,0xfa,0x7b,0x76,0x6c,0xfb,0x3d,
  0xa1,0x75,0xc8,0xda,0x4b,0xd2,0xed,0x67,0x7a,0x72,0xa6,0xfa,0x5f,0x31,0xb6,0x9f,
  0x36,0x7c,0x8d,0xaa,0x2f,0x39,0x2a,0x7d,0x56,0xb5,0xc3,0x10,0x7e,0x66,0xb0,0x9,
  0xb,0x76,0xa0,0x11,0x92,0x32,0x65,0xb5,0x29,0xa8,0x14,0x76,0xc6,0x30,0x84,0x10,
  0xe5,0xd4,0xcd,0x3,0xc4,0xa7,0x74,0xde,0xba,0x24,0x1a,0x10,0xa,0x23,0xc5,0x32,
  0xba,0xf5,0xf2,0x64,0xc5,0x8e,0x77,0x6,0x13,0x6b,0x56,0xb5,0x17,0x96,0xac,0xb8,
  0xfb,0x6,0x7c,0x1f,0xb0,0x7b,0x28,0x98,0x1c,0x60,0x52,0xb0,0x46,0x26,0x48,0xcd,
  0xac,0x30,0x4f,0xbb,0x79,0x32,0x69,0x26,0x24,0xe0,0x4f,0x9f,0xee,0x78,0xf7,0x47,
  0x30,0x47,0x20,0x20,0x4d,0xcc,0x38,0xe2,0x5,0x81,0xde,0x9c,0x1d,0xd9,0x68,0x1b,
  0xf,0xec,0xb8,0xf0,0x67,0xdd,0xa5,0x9,0x9d,0xc6,0xb6,0x22,0x29,0x2c,0xe9,0xfc,
  0x92,0x12,0xae,0xc5,0xda,0x16,0x17,0xb4,0xfe,0xdc,0x1e,0xd3,0x5a,0xb1,0x45,0xb8,
  0x52,0x5d,0x5c,0x67,0x99,0x95,0xef,0x55,0x4a,0x2d,0x47,0x3e,0x1e,0x26,0x93,0x87,
  0xb6,0xb1,0x29,0xc2,0x3b,0xb3,0x5b,0xf,0x87,0xdc,0x6b,0xd5,0x4a,0xdd,0x8e,0x2f,
  0x39,0xe0,0x74,0x60,0xbc,0xab,0x9d,0x15,0x2,0xd8,0x29,0xdc,0xcb,0x16,0xbb,0xc,
  0x1c,0x5a,0xd9,0xdd,0x50,0xc8,0x3c,0xeb,0xb6,0x27,0x16,0xc,0x6d,0xf1,0xea,0xf7,
  0x12,0x6,0x4e,0x10,0x8c,0x35,0xfb,0xe3,0xc7,0xda,0x6d,0x89,0x15,0x74,0x7e,0xe4,
  0xf8,0x91,0x27,0xdf,0xe,0xb7,0x99,0x6b,0x99,0x37,0x99,0x72,0x6a,0x4f,0x66,0xb8,
  0xd9,0x7,0x2c,0x64,0xa7,0xa6,0x44,0xac,0xf9,0x2a,0xb,0x27,0x71,0xe1,0x4b,0x25,
  0xf0,0x40,0xca,0x46,0x26,0xdf,0x5d,0xf7,0x23,0x66,0x83,0x78,0xee,0x75,0xfd,0x33,
  0xd3,0xe4,0x4d,0x90,0xb,0x19,0x0,0x1d,0xac,0x2a,0xd7,0xbb,0x45,0x5a,0xa0,0xa,
  
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // rocs
  0x0,0x4,
  0x0,0x7,0x95,0xa3,
  0x0,0x72,
  0x0,0x6f,0x0,0x63,0x0,0x73,
    // rocsui.rc
  0x0,0x9,
  0xa,0xab,0x77,0x23,
  0x0,0x72,
  0x0,0x6f,0x0,0x63,0x0,0x73,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xb7,0x8d,0x8c,0xd8,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xb7,0x8d,0x8c,0xd8,
  // :/kxmlgui5/rocs
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xb7,0x8d,0x8c,0xd8,
  // :/kxmlgui5/rocs/rocsui.rc
  0x0,0x0,0x0,0x24,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xb7,0x8d,0x8c,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_rocs)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_rocs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_rocs)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_rocs)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_rocs)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_rocs)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
