/********************************************************************************
** Form generated from reading UI file 'assignvalueswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASSIGNVALUESWIDGET_H
#define UI_ASSIGNVALUESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_AssignValuesWidget
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *advancedLayout;
    QLabel *property_choice_label;
    QPushButton *buttonShowAdvanced;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_5;
    QComboBox *comboBoxMethod;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QGridLayout *gridLayout;
    QFormLayout *formLayout;
    QLabel *IDlabelStartValue;
    QSpinBox *spinBoxIDStartValue;
    QFrame *line;
    QWidget *page_2;
    QGridLayout *gridLayout_9;
    QFormLayout *formLayout_2;
    QLabel *LabelInitialString;
    QLineEdit *LineEditInitialString;
    QWidget *page_5;
    QGridLayout *gridLayout_8;
    QFormLayout *formLayout_5;
    QLabel *LabelAlphaNumericID;
    QSpinBox *SpinBoxAlphaNumericIDStart;
    QLabel *LabelAlphaNumericPrefix;
    QLineEdit *LineEditAlphaNumericPrefix;
    QWidget *page_3;
    QGridLayout *gridLayout_3;
    QFormLayout *formLayout_3;
    QLabel *label_5;
    QSpinBox *spinBoxIntegerLowerLimit;
    QLabel *label_6;
    QLabel *label_7;
    QSpinBox *spinBoxIntegerGeneratorSeed;
    QSpinBox *spinBoxIntegerUpperLimit;
    QWidget *page_4;
    QGridLayout *gridLayout_4;
    QFormLayout *formLayout_4;
    QLabel *label_4;
    QLabel *label_8;
    QLabel *label_9;
    QDoubleSpinBox *spinBoxFloatLowerLimit;
    QDoubleSpinBox *spinBoxFloatUpperLimit;
    QSpinBox *spinBoxFloatGeneratorSeed;
    QWidget *page_6;
    QGridLayout *gridLayout_6;
    QFormLayout *formLayout_7;
    QLabel *constant_label;
    QLineEdit *lineEditConstantValue;
    QGridLayout *groupOverwrite;
    QCheckBox *checkBoxOverwriteValues;
    QLabel *label;
    QDialogButtonBox *buttons;
    QWidget *groupTarget;
    QGridLayout *gridLayout_7;
    QLabel *labelData;
    KLineEdit *propertyName;
    QLabel *labelProperty;
    QLabel *labelConnection;
    QHBoxLayout *horizontalLayout;
    QComboBox *edgeType;
    QRadioButton *applyToEdges;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *nodeType;
    QRadioButton *applyToNodes;

    void setupUi(QWidget *AssignValuesWidget)
    {
        if (AssignValuesWidget->objectName().isEmpty())
            AssignValuesWidget->setObjectName("AssignValuesWidget");
        AssignValuesWidget->resize(350, 403);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AssignValuesWidget->sizePolicy().hasHeightForWidth());
        AssignValuesWidget->setSizePolicy(sizePolicy);
        AssignValuesWidget->setMinimumSize(QSize(350, 0));
        AssignValuesWidget->setBaseSize(QSize(0, 0));
        gridLayout_2 = new QGridLayout(AssignValuesWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        advancedLayout = new QHBoxLayout();
        advancedLayout->setObjectName("advancedLayout");
        property_choice_label = new QLabel(AssignValuesWidget);
        property_choice_label->setObjectName("property_choice_label");

        advancedLayout->addWidget(property_choice_label);

        buttonShowAdvanced = new QPushButton(AssignValuesWidget);
        buttonShowAdvanced->setObjectName("buttonShowAdvanced");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonShowAdvanced->sizePolicy().hasHeightForWidth());
        buttonShowAdvanced->setSizePolicy(sizePolicy1);
        buttonShowAdvanced->setMaximumSize(QSize(24, 24));
        buttonShowAdvanced->setCheckable(true);

        advancedLayout->addWidget(buttonShowAdvanced, 0, Qt::AlignRight);


        gridLayout_2->addLayout(advancedLayout, 0, 1, 1, 1);

        groupBox = new QGroupBox(AssignValuesWidget);
        groupBox->setObjectName("groupBox");
        gridLayout_5 = new QGridLayout(groupBox);
        gridLayout_5->setObjectName("gridLayout_5");
        comboBoxMethod = new QComboBox(groupBox);
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->setObjectName("comboBoxMethod");

        gridLayout_5->addWidget(comboBoxMethod, 0, 0, 1, 1);

        stackedWidget = new QStackedWidget(groupBox);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        page->setMinimumSize(QSize(0, 115));
        gridLayout = new QGridLayout(page);
        gridLayout->setObjectName("gridLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        IDlabelStartValue = new QLabel(page);
        IDlabelStartValue->setObjectName("IDlabelStartValue");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, IDlabelStartValue);

        spinBoxIDStartValue = new QSpinBox(page);
        spinBoxIDStartValue->setObjectName("spinBoxIDStartValue");
        spinBoxIDStartValue->setMinimum(-100000);
        spinBoxIDStartValue->setMaximum(100000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, spinBoxIDStartValue);


        gridLayout->addLayout(formLayout, 0, 0, 1, 1);

        line = new QFrame(page);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 1);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_9 = new QGridLayout(page_2);
        gridLayout_9->setObjectName("gridLayout_9");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        LabelInitialString = new QLabel(page_2);
        LabelInitialString->setObjectName("LabelInitialString");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, LabelInitialString);

        LineEditInitialString = new QLineEdit(page_2);
        LineEditInitialString->setObjectName("LineEditInitialString");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, LineEditInitialString);


        gridLayout_9->addLayout(formLayout_2, 0, 0, 1, 1);

        stackedWidget->addWidget(page_2);
        page_5 = new QWidget();
        page_5->setObjectName("page_5");
        gridLayout_8 = new QGridLayout(page_5);
        gridLayout_8->setObjectName("gridLayout_8");
        formLayout_5 = new QFormLayout();
        formLayout_5->setObjectName("formLayout_5");
        formLayout_5->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        LabelAlphaNumericID = new QLabel(page_5);
        LabelAlphaNumericID->setObjectName("LabelAlphaNumericID");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, LabelAlphaNumericID);

        SpinBoxAlphaNumericIDStart = new QSpinBox(page_5);
        SpinBoxAlphaNumericIDStart->setObjectName("SpinBoxAlphaNumericIDStart");
        SpinBoxAlphaNumericIDStart->setMinimum(-100000);
        SpinBoxAlphaNumericIDStart->setValue(0);

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, SpinBoxAlphaNumericIDStart);

        LabelAlphaNumericPrefix = new QLabel(page_5);
        LabelAlphaNumericPrefix->setObjectName("LabelAlphaNumericPrefix");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, LabelAlphaNumericPrefix);

        LineEditAlphaNumericPrefix = new QLineEdit(page_5);
        LineEditAlphaNumericPrefix->setObjectName("LineEditAlphaNumericPrefix");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, LineEditAlphaNumericPrefix);


        gridLayout_8->addLayout(formLayout_5, 0, 0, 1, 1);

        stackedWidget->addWidget(page_5);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        gridLayout_3 = new QGridLayout(page_3);
        gridLayout_3->setObjectName("gridLayout_3");
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_5 = new QLabel(page_3);
        label_5->setObjectName("label_5");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        spinBoxIntegerLowerLimit = new QSpinBox(page_3);
        spinBoxIntegerLowerLimit->setObjectName("spinBoxIntegerLowerLimit");
        spinBoxIntegerLowerLimit->setMinimum(-99999);
        spinBoxIntegerLowerLimit->setMaximum(99999);
        spinBoxIntegerLowerLimit->setValue(1);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, spinBoxIntegerLowerLimit);

        label_6 = new QLabel(page_3);
        label_6->setObjectName("label_6");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_6);

        label_7 = new QLabel(page_3);
        label_7->setObjectName("label_7");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_7);

        spinBoxIntegerGeneratorSeed = new QSpinBox(page_3);
        spinBoxIntegerGeneratorSeed->setObjectName("spinBoxIntegerGeneratorSeed");
        spinBoxIntegerGeneratorSeed->setMinimum(1);
        spinBoxIntegerGeneratorSeed->setMaximum(99999);
        spinBoxIntegerGeneratorSeed->setValue(1);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, spinBoxIntegerGeneratorSeed);

        spinBoxIntegerUpperLimit = new QSpinBox(page_3);
        spinBoxIntegerUpperLimit->setObjectName("spinBoxIntegerUpperLimit");
        spinBoxIntegerUpperLimit->setMinimum(-99999);
        spinBoxIntegerUpperLimit->setMaximum(99999);
        spinBoxIntegerUpperLimit->setValue(100);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, spinBoxIntegerUpperLimit);


        gridLayout_3->addLayout(formLayout_3, 0, 0, 1, 1);

        stackedWidget->addWidget(page_3);
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        gridLayout_4 = new QGridLayout(page_4);
        gridLayout_4->setObjectName("gridLayout_4");
        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        label_4 = new QLabel(page_4);
        label_4->setObjectName("label_4");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        label_8 = new QLabel(page_4);
        label_8->setObjectName("label_8");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        label_9 = new QLabel(page_4);
        label_9->setObjectName("label_9");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, label_9);

        spinBoxFloatLowerLimit = new QDoubleSpinBox(page_4);
        spinBoxFloatLowerLimit->setObjectName("spinBoxFloatLowerLimit");
        spinBoxFloatLowerLimit->setDecimals(3);
        spinBoxFloatLowerLimit->setMinimum(-99999.990000000005239);
        spinBoxFloatLowerLimit->setValue(0.000000000000000);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, spinBoxFloatLowerLimit);

        spinBoxFloatUpperLimit = new QDoubleSpinBox(page_4);
        spinBoxFloatUpperLimit->setObjectName("spinBoxFloatUpperLimit");
        spinBoxFloatUpperLimit->setDecimals(3);
        spinBoxFloatUpperLimit->setMinimum(-99999.990000000005239);
        spinBoxFloatUpperLimit->setMaximum(99999.990000000005239);
        spinBoxFloatUpperLimit->setValue(10.000000000000000);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, spinBoxFloatUpperLimit);

        spinBoxFloatGeneratorSeed = new QSpinBox(page_4);
        spinBoxFloatGeneratorSeed->setObjectName("spinBoxFloatGeneratorSeed");
        spinBoxFloatGeneratorSeed->setMinimum(1);
        spinBoxFloatGeneratorSeed->setMaximum(99999);
        spinBoxFloatGeneratorSeed->setValue(1);

        formLayout_4->setWidget(2, QFormLayout::ItemRole::FieldRole, spinBoxFloatGeneratorSeed);


        gridLayout_4->addLayout(formLayout_4, 0, 0, 1, 1);

        stackedWidget->addWidget(page_4);
        page_6 = new QWidget();
        page_6->setObjectName("page_6");
        gridLayout_6 = new QGridLayout(page_6);
        gridLayout_6->setObjectName("gridLayout_6");
        formLayout_7 = new QFormLayout();
        formLayout_7->setObjectName("formLayout_7");
        formLayout_7->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        constant_label = new QLabel(page_6);
        constant_label->setObjectName("constant_label");

        formLayout_7->setWidget(0, QFormLayout::ItemRole::LabelRole, constant_label);

        lineEditConstantValue = new QLineEdit(page_6);
        lineEditConstantValue->setObjectName("lineEditConstantValue");

        formLayout_7->setWidget(0, QFormLayout::ItemRole::FieldRole, lineEditConstantValue);


        gridLayout_6->addLayout(formLayout_7, 1, 0, 1, 1);

        stackedWidget->addWidget(page_6);

        gridLayout_5->addWidget(stackedWidget, 1, 0, 1, 1);

        groupOverwrite = new QGridLayout();
        groupOverwrite->setObjectName("groupOverwrite");
        checkBoxOverwriteValues = new QCheckBox(groupBox);
        checkBoxOverwriteValues->setObjectName("checkBoxOverwriteValues");
        checkBoxOverwriteValues->setChecked(true);

        groupOverwrite->addWidget(checkBoxOverwriteValues, 3, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        groupOverwrite->addWidget(label, 3, 0, 1, 1);


        gridLayout_5->addLayout(groupOverwrite, 2, 0, 1, 1);

        buttons = new QDialogButtonBox(groupBox);
        buttons->setObjectName("buttons");
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout_5->addWidget(buttons, 3, 0, 1, 1);


        gridLayout_2->addWidget(groupBox, 7, 1, 1, 1);

        groupTarget = new QWidget(AssignValuesWidget);
        groupTarget->setObjectName("groupTarget");
        groupTarget->setBaseSize(QSize(0, 0));
        gridLayout_7 = new QGridLayout(groupTarget);
        gridLayout_7->setObjectName("gridLayout_7");
        labelData = new QLabel(groupTarget);
        labelData->setObjectName("labelData");
        labelData->setLayoutDirection(Qt::LeftToRight);
        labelData->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_7->addWidget(labelData, 1, 0, 1, 1);

        propertyName = new KLineEdit(groupTarget);
        propertyName->setObjectName("propertyName");

        gridLayout_7->addWidget(propertyName, 2, 2, 1, 1);

        labelProperty = new QLabel(groupTarget);
        labelProperty->setObjectName("labelProperty");
        labelProperty->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_7->addWidget(labelProperty, 2, 0, 1, 1);

        labelConnection = new QLabel(groupTarget);
        labelConnection->setObjectName("labelConnection");
        labelConnection->setLayoutDirection(Qt::LeftToRight);
        labelConnection->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_7->addWidget(labelConnection, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        edgeType = new QComboBox(groupTarget);
        edgeType->setObjectName("edgeType");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(edgeType->sizePolicy().hasHeightForWidth());
        edgeType->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(edgeType);

        applyToEdges = new QRadioButton(groupTarget);
        applyToEdges->setObjectName("applyToEdges");
        applyToEdges->setChecked(true);

        horizontalLayout->addWidget(applyToEdges);


        gridLayout_7->addLayout(horizontalLayout, 0, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        nodeType = new QComboBox(groupTarget);
        nodeType->setObjectName("nodeType");
        sizePolicy2.setHeightForWidth(nodeType->sizePolicy().hasHeightForWidth());
        nodeType->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(nodeType);

        applyToNodes = new QRadioButton(groupTarget);
        applyToNodes->setObjectName("applyToNodes");

        horizontalLayout_2->addWidget(applyToNodes);


        gridLayout_7->addLayout(horizontalLayout_2, 1, 2, 1, 1);


        gridLayout_2->addWidget(groupTarget, 1, 1, 1, 1);


        retranslateUi(AssignValuesWidget);
        QObject::connect(comboBoxMethod, &QComboBox::currentIndexChanged, stackedWidget, &QStackedWidget::setCurrentIndex);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, checkBoxOverwriteValues, &QCheckBox::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, spinBoxIntegerGeneratorSeed, &QSpinBox::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_7, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, spinBoxFloatGeneratorSeed, &QSpinBox::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_9, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, LabelInitialString, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, LineEditInitialString, &QLineEdit::setVisible);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AssignValuesWidget);
    } // setupUi

    void retranslateUi(QWidget *AssignValuesWidget)
    {
        AssignValuesWidget->setWindowTitle(tr2i18n("Assign Values", nullptr));
        property_choice_label->setText(tr2i18n("Choose Properties", nullptr));
#if QT_CONFIG(tooltip)
        buttonShowAdvanced->setToolTip(tr2i18n("Show advanced options.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonShowAdvanced->setText(QString());
        groupBox->setTitle(tr2i18n("Assignment Method", nullptr));
        comboBoxMethod->setItemText(0, tr2i18n("Enumerate Items", nullptr));
        comboBoxMethod->setItemText(1, tr2i18n("Enumerate Alpha", nullptr));
        comboBoxMethod->setItemText(2, tr2i18n("Enumerate Alpha-Numeric", nullptr));
        comboBoxMethod->setItemText(3, tr2i18n("Assign Random Integers", nullptr));
        comboBoxMethod->setItemText(4, tr2i18n("Assign Random Reals", nullptr));
        comboBoxMethod->setItemText(5, tr2i18n("Assign Constant Value", nullptr));

        IDlabelStartValue->setText(tr2i18n("Start ID:", nullptr));
        LabelInitialString->setText(tr2i18n("Initial string", nullptr));
        LineEditInitialString->setText(tr2i18n("a", nullptr));
        LabelAlphaNumericID->setText(tr2i18n("Start ID", nullptr));
        LabelAlphaNumericPrefix->setText(tr2i18n("Prefix", nullptr));
        label_5->setText(tr2i18n("Lower Limit", nullptr));
        label_6->setText(tr2i18n("Upper Limit", nullptr));
        label_7->setText(tr2i18n("Generator Seed", nullptr));
        label_4->setText(tr2i18n("Lower Limit", nullptr));
        label_8->setText(tr2i18n("Upper Limit", nullptr));
        label_9->setText(tr2i18n("Generator Seed", nullptr));
        constant_label->setText(tr2i18n("Constant", nullptr));
        checkBoxOverwriteValues->setText(QString());
        label->setText(tr2i18n("Overwrite existing values", nullptr));
        labelData->setText(tr2i18n("Nodes:", nullptr));
        labelProperty->setText(tr2i18n("Property name:", nullptr));
        labelConnection->setText(tr2i18n("Edges:", nullptr));
#if QT_CONFIG(tooltip)
        applyToEdges->setToolTip(tr2i18n("Assign values to selected edges.", nullptr));
#endif // QT_CONFIG(tooltip)
        applyToEdges->setText(QString());
#if QT_CONFIG(tooltip)
        applyToNodes->setToolTip(tr2i18n("Assign values to selected nodes.", nullptr));
#endif // QT_CONFIG(tooltip)
        applyToNodes->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class AssignValuesWidget: public Ui_AssignValuesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ASSIGNVALUESWIDGET_H

