/********************************************************************************
** Form generated from reading UI file 'scriptapiwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTAPIWIDGET_H
#define UI_SCRIPTAPIWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScriptApiWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QStackedWidget *pageStack;
    QWidget *treeView;
    QVBoxLayout *verticalLayout_3;
    QTreeView *docTree;
    QWidget *detailsView;
    QVBoxLayout *verticalLayout_4;
    QTextBrowser *docDetails;
    QGridLayout *gridLayout_2;
    QPushButton *buttonHome;
    QPushButton *buttonPrev;
    QSpacerItem *horizontalSpacer;
    QPushButton *buttonTree;
    QFrame *line;
    QPushButton *buttonNext;

    void setupUi(QWidget *ScriptApiWidget)
    {
        if (ScriptApiWidget->objectName().isEmpty())
            ScriptApiWidget->setObjectName("ScriptApiWidget");
        ScriptApiWidget->resize(400, 333);
        verticalLayout = new QVBoxLayout(ScriptApiWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(ScriptApiWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        pageStack = new QStackedWidget(groupBox);
        pageStack->setObjectName("pageStack");
        treeView = new QWidget();
        treeView->setObjectName("treeView");
        verticalLayout_3 = new QVBoxLayout(treeView);
        verticalLayout_3->setObjectName("verticalLayout_3");
        docTree = new QTreeView(treeView);
        docTree->setObjectName("docTree");

        verticalLayout_3->addWidget(docTree);

        pageStack->addWidget(treeView);
        detailsView = new QWidget();
        detailsView->setObjectName("detailsView");
        verticalLayout_4 = new QVBoxLayout(detailsView);
        verticalLayout_4->setObjectName("verticalLayout_4");
        docDetails = new QTextBrowser(detailsView);
        docDetails->setObjectName("docDetails");

        verticalLayout_4->addWidget(docDetails);

        pageStack->addWidget(detailsView);

        gridLayout->addWidget(pageStack, 3, 0, 1, 1);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        buttonHome = new QPushButton(groupBox);
        buttonHome->setObjectName("buttonHome");
        buttonHome->setMaximumSize(QSize(24, 16777215));
        buttonHome->setBaseSize(QSize(0, 0));

        gridLayout_2->addWidget(buttonHome, 0, 3, 1, 1);

        buttonPrev = new QPushButton(groupBox);
        buttonPrev->setObjectName("buttonPrev");
        buttonPrev->setMaximumSize(QSize(24, 16777215));

        gridLayout_2->addWidget(buttonPrev, 0, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 6, 1, 1);

        buttonTree = new QPushButton(groupBox);
        buttonTree->setObjectName("buttonTree");
        buttonTree->setMaximumSize(QSize(24, 16777215));

        gridLayout_2->addWidget(buttonTree, 0, 0, 1, 1);

        line = new QFrame(groupBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line, 0, 2, 1, 1);

        buttonNext = new QPushButton(groupBox);
        buttonNext->setObjectName("buttonNext");
        buttonNext->setMaximumSize(QSize(24, 16777215));

        gridLayout_2->addWidget(buttonNext, 0, 5, 1, 1);


        gridLayout->addLayout(gridLayout_2, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox);


        retranslateUi(ScriptApiWidget);

        pageStack->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(ScriptApiWidget);
    } // setupUi

    void retranslateUi(QWidget *ScriptApiWidget)
    {
        groupBox->setTitle(tr2i18n("Rocs Scripting API", nullptr));
        (void)ScriptApiWidget;
    } // retranslateUi

};

namespace Ui {
    class ScriptApiWidget: public Ui_ScriptApiWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTAPIWIDGET_H

