/********************************************************************************
** Form generated from reading UI file 'scriptoutputwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTOUTPUTWIDGET_H
#define UI_SCRIPTOUTPUTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScriptOutputWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QWidget *header;
    QHBoxLayout *horizontalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QPushButton *buttonDisableClear;
    QPushButton *buttonEnableDebugOutput;
    QFrame *line;
    QPushButton *buttonClear;
    QWidget *body;
    QVBoxLayout *verticalLayout_4;
    QStackedWidget *output;
    QWidget *page1;
    QGridLayout *gridLayout;
    QTextBrowser *txtOutput;
    QWidget *page2;
    QGridLayout *gridLayout_2;
    QTextBrowser *dbgOutput;

    void setupUi(QWidget *ScriptOutputWidget)
    {
        if (ScriptOutputWidget->objectName().isEmpty())
            ScriptOutputWidget->setObjectName("ScriptOutputWidget");
        ScriptOutputWidget->resize(393, 292);
        verticalLayout_2 = new QVBoxLayout(ScriptOutputWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        header = new QWidget(ScriptOutputWidget);
        header->setObjectName("header");
        horizontalLayout_2 = new QHBoxLayout(header);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(header);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        buttonDisableClear = new QPushButton(header);
        buttonDisableClear->setObjectName("buttonDisableClear");
        buttonDisableClear->setMaximumSize(QSize(24, 16777215));
        buttonDisableClear->setCheckable(true);
        buttonDisableClear->setFlat(true);

        horizontalLayout->addWidget(buttonDisableClear);

        buttonEnableDebugOutput = new QPushButton(header);
        buttonEnableDebugOutput->setObjectName("buttonEnableDebugOutput");
        buttonEnableDebugOutput->setMaximumSize(QSize(24, 16777215));
        buttonEnableDebugOutput->setCheckable(true);
        buttonEnableDebugOutput->setFlat(true);

        horizontalLayout->addWidget(buttonEnableDebugOutput);

        line = new QFrame(header);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line);

        buttonClear = new QPushButton(header);
        buttonClear->setObjectName("buttonClear");
        buttonClear->setMaximumSize(QSize(24, 16777215));
        buttonClear->setCheckable(false);
        buttonClear->setFlat(true);

        horizontalLayout->addWidget(buttonClear);


        horizontalLayout_2->addLayout(horizontalLayout);


        verticalLayout->addWidget(header);

        body = new QWidget(ScriptOutputWidget);
        body->setObjectName("body");
        verticalLayout_4 = new QVBoxLayout(body);
        verticalLayout_4->setObjectName("verticalLayout_4");
        output = new QStackedWidget(body);
        output->setObjectName("output");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(output->sizePolicy().hasHeightForWidth());
        output->setSizePolicy(sizePolicy);
        output->setLineWidth(1);
        page1 = new QWidget();
        page1->setObjectName("page1");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(page1->sizePolicy().hasHeightForWidth());
        page1->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(page1);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, -1, 0, -1);
        txtOutput = new QTextBrowser(page1);
        txtOutput->setObjectName("txtOutput");
        sizePolicy1.setHeightForWidth(txtOutput->sizePolicy().hasHeightForWidth());
        txtOutput->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(txtOutput, 0, 0, 1, 1);

        output->addWidget(page1);
        page2 = new QWidget();
        page2->setObjectName("page2");
        gridLayout_2 = new QGridLayout(page2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, -1, 0, -1);
        dbgOutput = new QTextBrowser(page2);
        dbgOutput->setObjectName("dbgOutput");

        gridLayout_2->addWidget(dbgOutput, 0, 0, 1, 1);

        output->addWidget(page2);

        verticalLayout_4->addWidget(output);


        verticalLayout->addWidget(body);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(ScriptOutputWidget);

        output->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ScriptOutputWidget);
    } // setupUi

    void retranslateUi(QWidget *ScriptOutputWidget)
    {
        label->setText(tr2i18n("Script output:", nullptr));
#if QT_CONFIG(tooltip)
        buttonDisableClear->setToolTip(tr2i18n("Clear program output with each execution.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonEnableDebugOutput->setToolTip(tr2i18n("Show debug output.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonClear->setToolTip(tr2i18n("Clear output.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ScriptOutputWidget;
    } // retranslateUi

};

namespace Ui {
    class ScriptOutputWidget: public Ui_ScriptOutputWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTOUTPUTWIDGET_H

