/****************************************************************************
** Meta object code from reading C++ file 'documentwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/libgraphtheory/kernel/documentwrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphTheory::DocumentWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphTheory::DocumentWrapper",
        "message",
        "",
        "messageString",
        "GraphTheory::MessageType",
        "type",
        "registerWrapper",
        "NodePtr",
        "node",
        "EdgePtr",
        "edge",
        "QJSValue",
        "id",
        "nodes",
        "edges",
        "createNode",
        "x",
        "y",
        "createEdge",
        "GraphTheory::NodeWrapper*",
        "from",
        "to",
        "remove",
        "object"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'message'
        QtMocHelpers::SignalData<void(const QString &, GraphTheory::MessageType) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'registerWrapper'
        QtMocHelpers::SlotData<void(NodePtr)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'registerWrapper'
        QtMocHelpers::SlotData<void(EdgePtr)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'node'
        QtMocHelpers::MethodData<QJSValue(int) const>(8, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'nodes'
        QtMocHelpers::MethodData<QJSValue() const>(13, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'nodes'
        QtMocHelpers::MethodData<QJSValue(int) const>(13, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'edges'
        QtMocHelpers::MethodData<QJSValue() const>(14, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'edges'
        QtMocHelpers::MethodData<QJSValue(int) const>(14, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'createNode'
        QtMocHelpers::MethodData<QJSValue(int, int)>(15, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 17 },
        }}),
        // Method 'createEdge'
        QtMocHelpers::MethodData<QJSValue(GraphTheory::NodeWrapper *, GraphTheory::NodeWrapper *)>(18, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 19, 21 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<void(const QJSValue &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentWrapper, qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphTheory::DocumentWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>.metaTypes,
    nullptr
} };

void GraphTheory::DocumentWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GraphTheory::MessageType>>(_a[2]))); break;
        case 1: _t->registerWrapper((*reinterpret_cast<std::add_pointer_t<NodePtr>>(_a[1]))); break;
        case 2: _t->registerWrapper((*reinterpret_cast<std::add_pointer_t<EdgePtr>>(_a[1]))); break;
        case 3: { QJSValue _r = _t->node((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->nodes();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->nodes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->edges();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->edges((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->createNode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->createEdge((*reinterpret_cast<std::add_pointer_t<GraphTheory::NodeWrapper*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GraphTheory::NodeWrapper*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->remove((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentWrapper::*)(const QString & , GraphTheory::MessageType ) const>(_a, &DocumentWrapper::message, 0))
            return;
    }
}

const QMetaObject *GraphTheory::DocumentWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphTheory::DocumentWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11GraphTheory15DocumentWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GraphTheory::DocumentWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void GraphTheory::DocumentWrapper::message(const QString & _t1, GraphTheory::MessageType _t2)const
{
    QMetaObject::activate<void>(const_cast< GraphTheory::DocumentWrapper *>(this), &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
