/********************************************************************************
** Form generated from reading UI file 'journalwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOURNALWIDGET_H
#define UI_JOURNALWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "krichtextedit.h"
#include "krichtextwidget.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_JournalEditorWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    KRichTextWidget *editor;

    void setupUi(QWidget *JournalEditorWidget)
    {
        if (JournalEditorWidget->objectName().isEmpty())
            JournalEditorWidget->setObjectName("JournalEditorWidget");
        JournalEditorWidget->resize(400, 300);
        verticalLayout_2 = new QVBoxLayout(JournalEditorWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(JournalEditorWidget);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        editor = new KRichTextWidget(groupBox);
        editor->setObjectName("editor");
        editor->setRichTextSupport(KRichTextWidget::SupportAlignment|KRichTextWidget::SupportBold|KRichTextWidget::SupportChangeListStyle|KRichTextWidget::SupportDedentLists|KRichTextWidget::SupportDirection|KRichTextWidget::SupportFontSize|KRichTextWidget::SupportHyperlinks|KRichTextWidget::SupportIndentLists|KRichTextWidget::SupportItalic|KRichTextWidget::SupportRuleLine|KRichTextWidget::SupportSuperScriptAndSubScript|KRichTextWidget::SupportToPlainText);

        gridLayout_2->addWidget(editor, 0, 0, 1, 1);


        verticalLayout_2->addWidget(groupBox);


        retranslateUi(JournalEditorWidget);

        QMetaObject::connectSlotsByName(JournalEditorWidget);
    } // setupUi

    void retranslateUi(QWidget *JournalEditorWidget)
    {
        groupBox->setTitle(tr2i18n("Project Journal", nullptr));
        (void)JournalEditorWidget;
    } // retranslateUi

};

namespace Ui {
    class JournalEditorWidget: public Ui_JournalEditorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOURNALWIDGET_H

