/********************************************************************************
** Form generated from reading UI file 'graphlayoutwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GRAPHLAYOUTWIDGET_H
#define UI_GRAPHLAYOUTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GraphLayoutWidget
{
public:
    QTabWidget *tabs;
    QWidget *forceBasedLayoutTab;
    QWidget *formLayoutWidget;
    QFormLayout *forceBasedLayoutTabFormLayout;
    QLabel *areaFactorLabel;
    QSlider *areaFactorSlider;
    QLabel *repellingForceLabel;
    QSlider *repellingForceSlider;
    QLabel *attractionForceLabel;
    QSlider *attractionForceSlider;
    QWidget *radialTreeLayoutTab;
    QWidget *formLayoutWidget_2;
    QFormLayout *radialTreeLayoutTabFormLayout;
    QLabel *rootLabel;
    QComboBox *rootComboBox;
    QLabel *nodeSeparationLabel;
    QSlider *nodeSeparationSlider;
    QLabel *treeTypeLabel;
    QRadioButton *freeTreeRadioButton;
    QRadioButton *rootedTreeRadioButton;
    QDialogButtonBox *mainButtons;

    void setupUi(QWidget *GraphLayoutWidget)
    {
        if (GraphLayoutWidget->objectName().isEmpty())
            GraphLayoutWidget->setObjectName("GraphLayoutWidget");
        GraphLayoutWidget->resize(374, 264);
        GraphLayoutWidget->setMinimumSize(QSize(374, 264));
        tabs = new QTabWidget(GraphLayoutWidget);
        tabs->setObjectName("tabs");
        tabs->setGeometry(QRect(10, 10, 351, 191));
        forceBasedLayoutTab = new QWidget();
        forceBasedLayoutTab->setObjectName("forceBasedLayoutTab");
        formLayoutWidget = new QWidget(forceBasedLayoutTab);
        formLayoutWidget->setObjectName("formLayoutWidget");
        formLayoutWidget->setGeometry(QRect(40, 30, 271, 81));
        forceBasedLayoutTabFormLayout = new QFormLayout(formLayoutWidget);
        forceBasedLayoutTabFormLayout->setObjectName("forceBasedLayoutTabFormLayout");
        forceBasedLayoutTabFormLayout->setHorizontalSpacing(16);
        forceBasedLayoutTabFormLayout->setVerticalSpacing(16);
        forceBasedLayoutTabFormLayout->setContentsMargins(0, 0, 0, 0);
        areaFactorLabel = new QLabel(formLayoutWidget);
        areaFactorLabel->setObjectName("areaFactorLabel");

        forceBasedLayoutTabFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, areaFactorLabel);

        areaFactorSlider = new QSlider(formLayoutWidget);
        areaFactorSlider->setObjectName("areaFactorSlider");
        areaFactorSlider->setMinimum(1);
        areaFactorSlider->setMaximum(100);
        areaFactorSlider->setOrientation(Qt::Horizontal);

        forceBasedLayoutTabFormLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, areaFactorSlider);

        repellingForceLabel = new QLabel(formLayoutWidget);
        repellingForceLabel->setObjectName("repellingForceLabel");

        forceBasedLayoutTabFormLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, repellingForceLabel);

        repellingForceSlider = new QSlider(formLayoutWidget);
        repellingForceSlider->setObjectName("repellingForceSlider");
        repellingForceSlider->setMinimum(1);
        repellingForceSlider->setMaximum(100);
        repellingForceSlider->setOrientation(Qt::Horizontal);

        forceBasedLayoutTabFormLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, repellingForceSlider);

        attractionForceLabel = new QLabel(formLayoutWidget);
        attractionForceLabel->setObjectName("attractionForceLabel");

        forceBasedLayoutTabFormLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, attractionForceLabel);

        attractionForceSlider = new QSlider(formLayoutWidget);
        attractionForceSlider->setObjectName("attractionForceSlider");
        attractionForceSlider->setMinimum(1);
        attractionForceSlider->setMaximum(100);
        attractionForceSlider->setOrientation(Qt::Horizontal);

        forceBasedLayoutTabFormLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, attractionForceSlider);

        tabs->addTab(forceBasedLayoutTab, QString());
        radialTreeLayoutTab = new QWidget();
        radialTreeLayoutTab->setObjectName("radialTreeLayoutTab");
        formLayoutWidget_2 = new QWidget(radialTreeLayoutTab);
        formLayoutWidget_2->setObjectName("formLayoutWidget_2");
        formLayoutWidget_2->setGeometry(QRect(20, 10, 301, 131));
        radialTreeLayoutTabFormLayout = new QFormLayout(formLayoutWidget_2);
        radialTreeLayoutTabFormLayout->setObjectName("radialTreeLayoutTabFormLayout");
        radialTreeLayoutTabFormLayout->setContentsMargins(0, 0, 0, 0);
        rootLabel = new QLabel(formLayoutWidget_2);
        rootLabel->setObjectName("rootLabel");

        radialTreeLayoutTabFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, rootLabel);

        rootComboBox = new QComboBox(formLayoutWidget_2);
        rootComboBox->setObjectName("rootComboBox");

        radialTreeLayoutTabFormLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, rootComboBox);

        nodeSeparationLabel = new QLabel(formLayoutWidget_2);
        nodeSeparationLabel->setObjectName("nodeSeparationLabel");

        radialTreeLayoutTabFormLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, nodeSeparationLabel);

        nodeSeparationSlider = new QSlider(formLayoutWidget_2);
        nodeSeparationSlider->setObjectName("nodeSeparationSlider");
        nodeSeparationSlider->setOrientation(Qt::Horizontal);

        radialTreeLayoutTabFormLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, nodeSeparationSlider);

        treeTypeLabel = new QLabel(formLayoutWidget_2);
        treeTypeLabel->setObjectName("treeTypeLabel");

        radialTreeLayoutTabFormLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, treeTypeLabel);

        freeTreeRadioButton = new QRadioButton(formLayoutWidget_2);
        freeTreeRadioButton->setObjectName("freeTreeRadioButton");
        freeTreeRadioButton->setChecked(true);

        radialTreeLayoutTabFormLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, freeTreeRadioButton);

        rootedTreeRadioButton = new QRadioButton(formLayoutWidget_2);
        rootedTreeRadioButton->setObjectName("rootedTreeRadioButton");

        radialTreeLayoutTabFormLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, rootedTreeRadioButton);

        tabs->addTab(radialTreeLayoutTab, QString());
        mainButtons = new QDialogButtonBox(GraphLayoutWidget);
        mainButtons->setObjectName("mainButtons");
        mainButtons->setGeometry(QRect(190, 220, 171, 32));
        mainButtons->setMinimumSize(QSize(171, 32));
        mainButtons->setOrientation(Qt::Horizontal);
        mainButtons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        retranslateUi(GraphLayoutWidget);

        tabs->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(GraphLayoutWidget);
    } // setupUi

    void retranslateUi(QWidget *GraphLayoutWidget)
    {
        GraphLayoutWidget->setWindowTitle(tr2i18n("Graph Layout", nullptr));
        areaFactorLabel->setText(tr2i18n("Area factor:", nullptr));
        repellingForceLabel->setText(tr2i18n("Repelling force:", nullptr));
        attractionForceLabel->setText(tr2i18n("Attraction force:", nullptr));
        tabs->setTabText(tabs->indexOf(forceBasedLayoutTab), tr2i18n("Force Based Layout", nullptr));
        rootLabel->setText(tr2i18n("Center/Root:", nullptr));
        nodeSeparationLabel->setText(tr2i18n("Node separation:", nullptr));
        treeTypeLabel->setText(tr2i18n("Tree type:", nullptr));
        freeTreeRadioButton->setText(tr2i18n("Free tree", nullptr));
        rootedTreeRadioButton->setText(tr2i18n("Rooted tree", nullptr));
        tabs->setTabText(tabs->indexOf(radialTreeLayoutTab), tr2i18n("Radial Tree Layout", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GraphLayoutWidget: public Ui_GraphLayoutWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GRAPHLAYOUTWIDGET_H

