/********************************************************************************
** Form generated from reading UI file 'transformedgeswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSFORMEDGESWIDGET_H
#define UI_TRANSFORMEDGESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TransformEdgesWidget
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QRadioButton *radioButtonMakeComplete;
    QRadioButton *radioButtonEraseEdges;
    QRadioButton *radioButtonReverseEdges;
    QRadioButton *radioButtonMakeSpanningtree;
    QRadioButton *radioButtonEraseSelfEdges;
    QDialogButtonBox *buttons;

    void setupUi(QWidget *TransformEdgesWidget)
    {
        if (TransformEdgesWidget->objectName().isEmpty())
            TransformEdgesWidget->setObjectName("TransformEdgesWidget");
        TransformEdgesWidget->resize(307, 218);
        gridLayout = new QGridLayout(TransformEdgesWidget);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        radioButtonMakeComplete = new QRadioButton(TransformEdgesWidget);
        radioButtonMakeComplete->setObjectName("radioButtonMakeComplete");
        radioButtonMakeComplete->setChecked(true);

        verticalLayout->addWidget(radioButtonMakeComplete);

        radioButtonEraseEdges = new QRadioButton(TransformEdgesWidget);
        radioButtonEraseEdges->setObjectName("radioButtonEraseEdges");

        verticalLayout->addWidget(radioButtonEraseEdges);

        radioButtonReverseEdges = new QRadioButton(TransformEdgesWidget);
        radioButtonReverseEdges->setObjectName("radioButtonReverseEdges");

        verticalLayout->addWidget(radioButtonReverseEdges);

        radioButtonMakeSpanningtree = new QRadioButton(TransformEdgesWidget);
        radioButtonMakeSpanningtree->setObjectName("radioButtonMakeSpanningtree");

        verticalLayout->addWidget(radioButtonMakeSpanningtree);

        radioButtonEraseSelfEdges = new QRadioButton(TransformEdgesWidget);
        radioButtonEraseSelfEdges->setObjectName("radioButtonEraseSelfEdges");

        verticalLayout->addWidget(radioButtonEraseSelfEdges);

        buttons = new QDialogButtonBox(TransformEdgesWidget);
        buttons->setObjectName("buttons");
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttons);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 2);


        retranslateUi(TransformEdgesWidget);

        QMetaObject::connectSlotsByName(TransformEdgesWidget);
    } // setupUi

    void retranslateUi(QWidget *TransformEdgesWidget)
    {
        TransformEdgesWidget->setWindowTitle(tr2i18n("Transform Edges", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonMakeComplete->setToolTip(tr2i18n("This option connects all nodes of the given graph. The new edges do not have any preset weights.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonMakeComplete->setText(tr2i18n("Complete graph", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonEraseEdges->setToolTip(tr2i18n("This option removes all edges from the given graph.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonEraseEdges->setText(tr2i18n("Remove all edges", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonReverseEdges->setToolTip(tr2i18n("This option reverses all edges of a directed graph. Note that this does not apply to undirected graphs.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonReverseEdges->setText(tr2i18n("Reverse all edges", nullptr));
#if QT_CONFIG(tooltip)
        radioButtonMakeSpanningtree->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">This option executes <span style=\" font-style:italic;\">Prim's Minimal Spanning Tree Algorithm</span> at the graph. All edges without given weights are assumed to have weights equals 1. Directed and undirected graphs are processed accordingly.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButtonMakeSpanningtree->setText(tr2i18n("Spanning tree transformation", nullptr));
        radioButtonEraseSelfEdges->setText(tr2i18n("Remove all self edges", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TransformEdgesWidget: public Ui_TransformEdgesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSFORMEDGESWIDGET_H

