/********************************************************************************
** Form generated from reading UI file 'generategraphwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERATEGRAPHWIDGET_H
#define UI_GENERATEGRAPHWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_GenerateGraphWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *advancedLayout;
    KComboBox *comboGraphGenerator;
    QPushButton *buttonShowAdvanced;
    QLineEdit *identifier;
    QLabel *labelNodeType;
    QLabel *labelIdentifier;
    QStackedWidget *stackedWidget;
    QWidget *page_mesh;
    QGridLayout *gridLayout_2;
    QFormLayout *formLayoutMesh;
    QLabel *label_columns;
    QSpinBox *meshColumns;
    QLabel *label_rows;
    QSpinBox *meshRows;
    QWidget *page_star;
    QGridLayout *gridLayout_3;
    QFormLayout *formLayoutStar;
    QLabel *label_numberSatellite;
    QSpinBox *starSatelliteNodes;
    QWidget *page_circle;
    QGridLayout *gridLayout_4;
    QFormLayout *formLayoutCircle;
    QLabel *label_numberCircle;
    QSpinBox *circleNodes;
    QWidget *page_random;
    QGridLayout *gridLayout_5;
    QFormLayout *formLayoutRandom;
    QLabel *label_randomNodes;
    QSpinBox *randomNodes;
    QLabel *label_randomEdges;
    QSpinBox *randomEdges;
    QLabel *label_randomSelfEdges;
    QLabel *label_randomGeneratorSeed;
    QSpinBox *randomGeneratorSeed;
    QCheckBox *randomAllowSelfedges;
    QWidget *page_gnp;
    QGridLayout *gridLayout_6;
    QFormLayout *formLayoutGNP;
    QLabel *label_GNPNodes;
    QLabel *label_GNPSelfEdges;
    QSpinBox *GNPNodes;
    QLabel *label_GNPEdgeProbability;
    QLabel *label_GNPGeneratorSeed;
    QSpinBox *GNPGeneratorSeed;
    QDoubleSpinBox *GNPEdgeProbability;
    QCheckBox *GNPAllowSelfedges;
    QWidget *page_random_tree;
    QGridLayout *gridLayout_8;
    QFormLayout *formLayoutRandomTree;
    QLabel *label_randomTreeNodes;
    QSpinBox *randomTreeNodes;
    QLabel *label_randomTreeGeneratorSeed;
    QSpinBox *randomTreeGeneratorSeed;
    QWidget *page_random_dag;
    QGridLayout *gridLayout_7;
    QFormLayout *formLayoutRandomDag;
    QLabel *label_numberNodes;
    QSpinBox *randomDagNumberOfNodes;
    QLabel *label_edgeProbability;
    QDoubleSpinBox *randomDagEdgeProbability;
    QLabel *label_dagGeneratorSeed;
    QSpinBox *dagGeneratorSeed;
    QWidget *page_path;
    QGridLayout *gridLayout_11;
    QFormLayout *formLayoutPath;
    QLabel *labe_pathNodes;
    QSpinBox *pathNodes;
    QWidget *page_complete;
    QGridLayout *gridLayout_10;
    QFormLayout *formLayoutComplete;
    QLabel *label_completeNodes;
    QSpinBox *completeNodes;
    QWidget *page_complete_bipartite;
    QGridLayout *gridLayout_12;
    QFormLayout *formLayoutCompleteBipartite;
    QLabel *label_completeBipartiteNodesLeft;
    QSpinBox *completeBipartiteNodesLeft;
    QLabel *label_completeBipartiteNodesRight;
    QSpinBox *completeBipartiteNodesRight;
    QDialogButtonBox *buttons;
    KComboBox *edgeTypeSelector;
    QFrame *line;
    QLabel *labelEdgeType;
    QLabel *labelGenerator;
    KComboBox *nodeTypeSelector;

    void setupUi(QWidget *GenerateGraphWidget)
    {
        if (GenerateGraphWidget->objectName().isEmpty())
            GenerateGraphWidget->setObjectName("GenerateGraphWidget");
        GenerateGraphWidget->resize(354, 423);
        gridLayout = new QGridLayout(GenerateGraphWidget);
        gridLayout->setObjectName("gridLayout");
        advancedLayout = new QHBoxLayout();
        advancedLayout->setObjectName("advancedLayout");
        comboGraphGenerator = new KComboBox(GenerateGraphWidget);
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->addItem(QString());
        comboGraphGenerator->setObjectName("comboGraphGenerator");

        advancedLayout->addWidget(comboGraphGenerator);

        buttonShowAdvanced = new QPushButton(GenerateGraphWidget);
        buttonShowAdvanced->setObjectName("buttonShowAdvanced");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonShowAdvanced->sizePolicy().hasHeightForWidth());
        buttonShowAdvanced->setSizePolicy(sizePolicy);
        buttonShowAdvanced->setMaximumSize(QSize(24, 24));
        buttonShowAdvanced->setCheckable(true);

        advancedLayout->addWidget(buttonShowAdvanced, 0, Qt::AlignRight);


        gridLayout->addLayout(advancedLayout, 0, 2, 1, 1);

        identifier = new QLineEdit(GenerateGraphWidget);
        identifier->setObjectName("identifier");

        gridLayout->addWidget(identifier, 1, 2, 1, 1);

        labelNodeType = new QLabel(GenerateGraphWidget);
        labelNodeType->setObjectName("labelNodeType");

        gridLayout->addWidget(labelNodeType, 3, 0, 1, 1);

        labelIdentifier = new QLabel(GenerateGraphWidget);
        labelIdentifier->setObjectName("labelIdentifier");

        gridLayout->addWidget(labelIdentifier, 1, 0, 1, 1);

        stackedWidget = new QStackedWidget(GenerateGraphWidget);
        stackedWidget->setObjectName("stackedWidget");
        page_mesh = new QWidget();
        page_mesh->setObjectName("page_mesh");
        gridLayout_2 = new QGridLayout(page_mesh);
        gridLayout_2->setObjectName("gridLayout_2");
        formLayoutMesh = new QFormLayout();
        formLayoutMesh->setObjectName("formLayoutMesh");
        formLayoutMesh->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_columns = new QLabel(page_mesh);
        label_columns->setObjectName("label_columns");

        formLayoutMesh->setWidget(0, QFormLayout::ItemRole::LabelRole, label_columns);

        meshColumns = new QSpinBox(page_mesh);
        meshColumns->setObjectName("meshColumns");
        meshColumns->setMinimum(1);
        meshColumns->setValue(5);

        formLayoutMesh->setWidget(0, QFormLayout::ItemRole::FieldRole, meshColumns);

        label_rows = new QLabel(page_mesh);
        label_rows->setObjectName("label_rows");

        formLayoutMesh->setWidget(1, QFormLayout::ItemRole::LabelRole, label_rows);

        meshRows = new QSpinBox(page_mesh);
        meshRows->setObjectName("meshRows");
        meshRows->setMinimum(1);
        meshRows->setValue(5);

        formLayoutMesh->setWidget(1, QFormLayout::ItemRole::FieldRole, meshRows);


        gridLayout_2->addLayout(formLayoutMesh, 0, 0, 1, 1);

        stackedWidget->addWidget(page_mesh);
        page_star = new QWidget();
        page_star->setObjectName("page_star");
        gridLayout_3 = new QGridLayout(page_star);
        gridLayout_3->setObjectName("gridLayout_3");
        formLayoutStar = new QFormLayout();
        formLayoutStar->setObjectName("formLayoutStar");
        label_numberSatellite = new QLabel(page_star);
        label_numberSatellite->setObjectName("label_numberSatellite");

        formLayoutStar->setWidget(0, QFormLayout::ItemRole::LabelRole, label_numberSatellite);

        starSatelliteNodes = new QSpinBox(page_star);
        starSatelliteNodes->setObjectName("starSatelliteNodes");
        starSatelliteNodes->setMinimum(1);
        starSatelliteNodes->setMaximum(999);
        starSatelliteNodes->setValue(10);

        formLayoutStar->setWidget(0, QFormLayout::ItemRole::FieldRole, starSatelliteNodes);


        gridLayout_3->addLayout(formLayoutStar, 0, 0, 1, 1);

        stackedWidget->addWidget(page_star);
        page_circle = new QWidget();
        page_circle->setObjectName("page_circle");
        gridLayout_4 = new QGridLayout(page_circle);
        gridLayout_4->setObjectName("gridLayout_4");
        formLayoutCircle = new QFormLayout();
        formLayoutCircle->setObjectName("formLayoutCircle");
        label_numberCircle = new QLabel(page_circle);
        label_numberCircle->setObjectName("label_numberCircle");

        formLayoutCircle->setWidget(0, QFormLayout::ItemRole::LabelRole, label_numberCircle);

        circleNodes = new QSpinBox(page_circle);
        circleNodes->setObjectName("circleNodes");
        circleNodes->setMinimum(1);
        circleNodes->setMaximum(999);
        circleNodes->setValue(10);

        formLayoutCircle->setWidget(0, QFormLayout::ItemRole::FieldRole, circleNodes);


        gridLayout_4->addLayout(formLayoutCircle, 0, 0, 1, 1);

        stackedWidget->addWidget(page_circle);
        page_random = new QWidget();
        page_random->setObjectName("page_random");
        gridLayout_5 = new QGridLayout(page_random);
        gridLayout_5->setObjectName("gridLayout_5");
        formLayoutRandom = new QFormLayout();
        formLayoutRandom->setObjectName("formLayoutRandom");
        label_randomNodes = new QLabel(page_random);
        label_randomNodes->setObjectName("label_randomNodes");

        formLayoutRandom->setWidget(0, QFormLayout::ItemRole::LabelRole, label_randomNodes);

        randomNodes = new QSpinBox(page_random);
        randomNodes->setObjectName("randomNodes");
        randomNodes->setMinimum(1);
        randomNodes->setMaximum(999);
        randomNodes->setValue(10);

        formLayoutRandom->setWidget(0, QFormLayout::ItemRole::FieldRole, randomNodes);

        label_randomEdges = new QLabel(page_random);
        label_randomEdges->setObjectName("label_randomEdges");

        formLayoutRandom->setWidget(1, QFormLayout::ItemRole::LabelRole, label_randomEdges);

        randomEdges = new QSpinBox(page_random);
        randomEdges->setObjectName("randomEdges");
        randomEdges->setValue(20);

        formLayoutRandom->setWidget(1, QFormLayout::ItemRole::FieldRole, randomEdges);

        label_randomSelfEdges = new QLabel(page_random);
        label_randomSelfEdges->setObjectName("label_randomSelfEdges");

        formLayoutRandom->setWidget(3, QFormLayout::ItemRole::LabelRole, label_randomSelfEdges);

        label_randomGeneratorSeed = new QLabel(page_random);
        label_randomGeneratorSeed->setObjectName("label_randomGeneratorSeed");

        formLayoutRandom->setWidget(2, QFormLayout::ItemRole::LabelRole, label_randomGeneratorSeed);

        randomGeneratorSeed = new QSpinBox(page_random);
        randomGeneratorSeed->setObjectName("randomGeneratorSeed");
        randomGeneratorSeed->setMinimum(1);
        randomGeneratorSeed->setMaximum(999999);

        formLayoutRandom->setWidget(2, QFormLayout::ItemRole::FieldRole, randomGeneratorSeed);

        randomAllowSelfedges = new QCheckBox(page_random);
        randomAllowSelfedges->setObjectName("randomAllowSelfedges");

        formLayoutRandom->setWidget(3, QFormLayout::ItemRole::FieldRole, randomAllowSelfedges);


        gridLayout_5->addLayout(formLayoutRandom, 0, 0, 1, 1);

        stackedWidget->addWidget(page_random);
        page_gnp = new QWidget();
        page_gnp->setObjectName("page_gnp");
        gridLayout_6 = new QGridLayout(page_gnp);
        gridLayout_6->setObjectName("gridLayout_6");
        formLayoutGNP = new QFormLayout();
        formLayoutGNP->setObjectName("formLayoutGNP");
        label_GNPNodes = new QLabel(page_gnp);
        label_GNPNodes->setObjectName("label_GNPNodes");

        formLayoutGNP->setWidget(0, QFormLayout::ItemRole::LabelRole, label_GNPNodes);

        label_GNPSelfEdges = new QLabel(page_gnp);
        label_GNPSelfEdges->setObjectName("label_GNPSelfEdges");

        formLayoutGNP->setWidget(3, QFormLayout::ItemRole::LabelRole, label_GNPSelfEdges);

        GNPNodes = new QSpinBox(page_gnp);
        GNPNodes->setObjectName("GNPNodes");
        GNPNodes->setMinimum(1);
        GNPNodes->setValue(10);

        formLayoutGNP->setWidget(0, QFormLayout::ItemRole::FieldRole, GNPNodes);

        label_GNPEdgeProbability = new QLabel(page_gnp);
        label_GNPEdgeProbability->setObjectName("label_GNPEdgeProbability");

        formLayoutGNP->setWidget(1, QFormLayout::ItemRole::LabelRole, label_GNPEdgeProbability);

        label_GNPGeneratorSeed = new QLabel(page_gnp);
        label_GNPGeneratorSeed->setObjectName("label_GNPGeneratorSeed");

        formLayoutGNP->setWidget(2, QFormLayout::ItemRole::LabelRole, label_GNPGeneratorSeed);

        GNPGeneratorSeed = new QSpinBox(page_gnp);
        GNPGeneratorSeed->setObjectName("GNPGeneratorSeed");
        GNPGeneratorSeed->setMinimum(1);
        GNPGeneratorSeed->setMaximum(999999);

        formLayoutGNP->setWidget(2, QFormLayout::ItemRole::FieldRole, GNPGeneratorSeed);

        GNPEdgeProbability = new QDoubleSpinBox(page_gnp);
        GNPEdgeProbability->setObjectName("GNPEdgeProbability");
        GNPEdgeProbability->setDecimals(3);
        GNPEdgeProbability->setMinimum(0.001000000000000);
        GNPEdgeProbability->setMaximum(1.000000000000000);
        GNPEdgeProbability->setValue(0.250000000000000);

        formLayoutGNP->setWidget(1, QFormLayout::ItemRole::FieldRole, GNPEdgeProbability);

        GNPAllowSelfedges = new QCheckBox(page_gnp);
        GNPAllowSelfedges->setObjectName("GNPAllowSelfedges");

        formLayoutGNP->setWidget(3, QFormLayout::ItemRole::FieldRole, GNPAllowSelfedges);


        gridLayout_6->addLayout(formLayoutGNP, 0, 0, 1, 1);

        stackedWidget->addWidget(page_gnp);
        page_random_tree = new QWidget();
        page_random_tree->setObjectName("page_random_tree");
        gridLayout_8 = new QGridLayout(page_random_tree);
        gridLayout_8->setObjectName("gridLayout_8");
        formLayoutRandomTree = new QFormLayout();
        formLayoutRandomTree->setObjectName("formLayoutRandomTree");
        label_randomTreeNodes = new QLabel(page_random_tree);
        label_randomTreeNodes->setObjectName("label_randomTreeNodes");

        formLayoutRandomTree->setWidget(0, QFormLayout::ItemRole::LabelRole, label_randomTreeNodes);

        randomTreeNodes = new QSpinBox(page_random_tree);
        randomTreeNodes->setObjectName("randomTreeNodes");
        randomTreeNodes->setMinimum(1);
        randomTreeNodes->setValue(10);

        formLayoutRandomTree->setWidget(0, QFormLayout::ItemRole::FieldRole, randomTreeNodes);

        label_randomTreeGeneratorSeed = new QLabel(page_random_tree);
        label_randomTreeGeneratorSeed->setObjectName("label_randomTreeGeneratorSeed");

        formLayoutRandomTree->setWidget(1, QFormLayout::ItemRole::LabelRole, label_randomTreeGeneratorSeed);

        randomTreeGeneratorSeed = new QSpinBox(page_random_tree);
        randomTreeGeneratorSeed->setObjectName("randomTreeGeneratorSeed");
        randomTreeGeneratorSeed->setMinimum(1);
        randomTreeGeneratorSeed->setMaximum(999999);

        formLayoutRandomTree->setWidget(1, QFormLayout::ItemRole::FieldRole, randomTreeGeneratorSeed);


        gridLayout_8->addLayout(formLayoutRandomTree, 0, 0, 1, 1);

        stackedWidget->addWidget(page_random_tree);
        page_random_dag = new QWidget();
        page_random_dag->setObjectName("page_random_dag");
        gridLayout_7 = new QGridLayout(page_random_dag);
        gridLayout_7->setObjectName("gridLayout_7");
        formLayoutRandomDag = new QFormLayout();
        formLayoutRandomDag->setObjectName("formLayoutRandomDag");
        label_numberNodes = new QLabel(page_random_dag);
        label_numberNodes->setObjectName("label_numberNodes");

        formLayoutRandomDag->setWidget(0, QFormLayout::ItemRole::LabelRole, label_numberNodes);

        randomDagNumberOfNodes = new QSpinBox(page_random_dag);
        randomDagNumberOfNodes->setObjectName("randomDagNumberOfNodes");
        randomDagNumberOfNodes->setMinimum(1);
        randomDagNumberOfNodes->setMaximum(999);

        formLayoutRandomDag->setWidget(0, QFormLayout::ItemRole::FieldRole, randomDagNumberOfNodes);

        label_edgeProbability = new QLabel(page_random_dag);
        label_edgeProbability->setObjectName("label_edgeProbability");

        formLayoutRandomDag->setWidget(1, QFormLayout::ItemRole::LabelRole, label_edgeProbability);

        randomDagEdgeProbability = new QDoubleSpinBox(page_random_dag);
        randomDagEdgeProbability->setObjectName("randomDagEdgeProbability");
        randomDagEdgeProbability->setMaximum(1.000000000000000);
        randomDagEdgeProbability->setSingleStep(0.100000000000000);
        randomDagEdgeProbability->setValue(0.500000000000000);

        formLayoutRandomDag->setWidget(1, QFormLayout::ItemRole::FieldRole, randomDagEdgeProbability);

        label_dagGeneratorSeed = new QLabel(page_random_dag);
        label_dagGeneratorSeed->setObjectName("label_dagGeneratorSeed");

        formLayoutRandomDag->setWidget(2, QFormLayout::ItemRole::LabelRole, label_dagGeneratorSeed);

        dagGeneratorSeed = new QSpinBox(page_random_dag);
        dagGeneratorSeed->setObjectName("dagGeneratorSeed");
        dagGeneratorSeed->setEnabled(true);

        formLayoutRandomDag->setWidget(2, QFormLayout::ItemRole::FieldRole, dagGeneratorSeed);


        gridLayout_7->addLayout(formLayoutRandomDag, 0, 0, 1, 1);

        stackedWidget->addWidget(page_random_dag);
        page_path = new QWidget();
        page_path->setObjectName("page_path");
        gridLayout_11 = new QGridLayout(page_path);
        gridLayout_11->setObjectName("gridLayout_11");
        formLayoutPath = new QFormLayout();
        formLayoutPath->setObjectName("formLayoutPath");
        labe_pathNodes = new QLabel(page_path);
        labe_pathNodes->setObjectName("labe_pathNodes");

        formLayoutPath->setWidget(0, QFormLayout::ItemRole::LabelRole, labe_pathNodes);

        pathNodes = new QSpinBox(page_path);
        pathNodes->setObjectName("pathNodes");
        pathNodes->setValue(4);

        formLayoutPath->setWidget(0, QFormLayout::ItemRole::FieldRole, pathNodes);


        gridLayout_11->addLayout(formLayoutPath, 0, 0, 1, 1);

        stackedWidget->addWidget(page_path);
        page_complete = new QWidget();
        page_complete->setObjectName("page_complete");
        gridLayout_10 = new QGridLayout(page_complete);
        gridLayout_10->setObjectName("gridLayout_10");
        formLayoutComplete = new QFormLayout();
        formLayoutComplete->setObjectName("formLayoutComplete");
        label_completeNodes = new QLabel(page_complete);
        label_completeNodes->setObjectName("label_completeNodes");

        formLayoutComplete->setWidget(0, QFormLayout::ItemRole::LabelRole, label_completeNodes);

        completeNodes = new QSpinBox(page_complete);
        completeNodes->setObjectName("completeNodes");
        completeNodes->setValue(5);

        formLayoutComplete->setWidget(0, QFormLayout::ItemRole::FieldRole, completeNodes);


        gridLayout_10->addLayout(formLayoutComplete, 0, 0, 1, 1);

        stackedWidget->addWidget(page_complete);
        page_complete_bipartite = new QWidget();
        page_complete_bipartite->setObjectName("page_complete_bipartite");
        gridLayout_12 = new QGridLayout(page_complete_bipartite);
        gridLayout_12->setObjectName("gridLayout_12");
        formLayoutCompleteBipartite = new QFormLayout();
        formLayoutCompleteBipartite->setObjectName("formLayoutCompleteBipartite");
        label_completeBipartiteNodesLeft = new QLabel(page_complete_bipartite);
        label_completeBipartiteNodesLeft->setObjectName("label_completeBipartiteNodesLeft");

        formLayoutCompleteBipartite->setWidget(0, QFormLayout::ItemRole::LabelRole, label_completeBipartiteNodesLeft);

        completeBipartiteNodesLeft = new QSpinBox(page_complete_bipartite);
        completeBipartiteNodesLeft->setObjectName("completeBipartiteNodesLeft");
        completeBipartiteNodesLeft->setValue(4);

        formLayoutCompleteBipartite->setWidget(0, QFormLayout::ItemRole::FieldRole, completeBipartiteNodesLeft);

        label_completeBipartiteNodesRight = new QLabel(page_complete_bipartite);
        label_completeBipartiteNodesRight->setObjectName("label_completeBipartiteNodesRight");

        formLayoutCompleteBipartite->setWidget(1, QFormLayout::ItemRole::LabelRole, label_completeBipartiteNodesRight);

        completeBipartiteNodesRight = new QSpinBox(page_complete_bipartite);
        completeBipartiteNodesRight->setObjectName("completeBipartiteNodesRight");
        completeBipartiteNodesRight->setValue(4);

        formLayoutCompleteBipartite->setWidget(1, QFormLayout::ItemRole::FieldRole, completeBipartiteNodesRight);


        gridLayout_12->addLayout(formLayoutCompleteBipartite, 0, 0, 1, 1);

        stackedWidget->addWidget(page_complete_bipartite);

        gridLayout->addWidget(stackedWidget, 6, 0, 1, 3);

        buttons = new QDialogButtonBox(GenerateGraphWidget);
        buttons->setObjectName("buttons");
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttons, 7, 2, 1, 1);

        edgeTypeSelector = new KComboBox(GenerateGraphWidget);
        edgeTypeSelector->setObjectName("edgeTypeSelector");

        gridLayout->addWidget(edgeTypeSelector, 2, 2, 1, 1);

        line = new QFrame(GenerateGraphWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 5, 0, 1, 3);

        labelEdgeType = new QLabel(GenerateGraphWidget);
        labelEdgeType->setObjectName("labelEdgeType");

        gridLayout->addWidget(labelEdgeType, 2, 0, 1, 1);

        labelGenerator = new QLabel(GenerateGraphWidget);
        labelGenerator->setObjectName("labelGenerator");

        gridLayout->addWidget(labelGenerator, 0, 0, 1, 1);

        nodeTypeSelector = new KComboBox(GenerateGraphWidget);
        nodeTypeSelector->setObjectName("nodeTypeSelector");

        gridLayout->addWidget(nodeTypeSelector, 3, 2, 1, 1);

#if QT_CONFIG(shortcut)
        label_columns->setBuddy(meshColumns);
        label_rows->setBuddy(meshRows);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GenerateGraphWidget);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_randomGeneratorSeed, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, randomGeneratorSeed, &QSpinBox::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_GNPGeneratorSeed, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, GNPGeneratorSeed, &QSpinBox::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_randomTreeGeneratorSeed, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, randomTreeGeneratorSeed, &QSpinBox::setVisible);
        QObject::connect(comboGraphGenerator, SIGNAL(currentIndexChanged(int)), stackedWidget, SLOT(setCurrentIndex(int)));
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, label_dagGeneratorSeed, &QLabel::setVisible);
        QObject::connect(buttonShowAdvanced, &QPushButton::toggled, dagGeneratorSeed, &QSpinBox::setVisible);

        stackedWidget->setCurrentIndex(3);


        QMetaObject::connectSlotsByName(GenerateGraphWidget);
    } // setupUi

    void retranslateUi(QWidget *GenerateGraphWidget)
    {
        GenerateGraphWidget->setWindowTitle(tr2i18n("Generate Graph", nullptr));
        comboGraphGenerator->setItemText(0, tr2i18n("Mesh Graph", nullptr));
        comboGraphGenerator->setItemText(1, tr2i18n("Star Graph", nullptr));
        comboGraphGenerator->setItemText(2, tr2i18n("Circle Graph", nullptr));
        comboGraphGenerator->setItemText(3, tr2i18n("Random Graph", nullptr));
        comboGraphGenerator->setItemText(4, tr2i18n("Erd\303\266s-Renyi Graph", nullptr));
        comboGraphGenerator->setItemText(5, tr2i18n("Random Tree Graph", nullptr));
        comboGraphGenerator->setItemText(6, tr2i18n("Random Dag Graph", nullptr));
        comboGraphGenerator->setItemText(7, tr2i18n("Path Graph", nullptr));
        comboGraphGenerator->setItemText(8, tr2i18n("Complete Graph", nullptr));
        comboGraphGenerator->setItemText(9, tr2i18n("Complete Bipartite", nullptr));

#if QT_CONFIG(tooltip)
        comboGraphGenerator->setToolTip(tr2i18n("Select the graph generator.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonShowAdvanced->setToolTip(tr2i18n("Show advanced settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonShowAdvanced->setText(QString());
#if QT_CONFIG(tooltip)
        identifier->setToolTip(tr2i18n("Set the unique identifier of the generated graph.", nullptr));
#endif // QT_CONFIG(tooltip)
        identifier->setText(tr2i18n("Graph", nullptr));
#if QT_CONFIG(tooltip)
        labelNodeType->setToolTip(tr2i18n("The node type to create the nodes of the graph with", nullptr));
#endif // QT_CONFIG(tooltip)
        labelNodeType->setText(tr2i18n("Node type:", nullptr));
#if QT_CONFIG(tooltip)
        labelIdentifier->setToolTip(tr2i18n("The identifier of the created graph (used for scripting)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelIdentifier->setText(tr2i18n("Identifier:", nullptr));
        label_columns->setText(tr2i18n("Number of Columns:", nullptr));
        label_rows->setText(tr2i18n("Number of Rows:", nullptr));
        label_numberSatellite->setText(tr2i18n("Satellite Nodes:", nullptr));
        label_numberCircle->setText(tr2i18n("Number of Nodes:", nullptr));
        label_randomNodes->setText(tr2i18n("Nodes:", nullptr));
        label_randomEdges->setText(tr2i18n("Edges:", nullptr));
        label_randomSelfEdges->setText(tr2i18n("Allow self-edges:", nullptr));
        label_randomGeneratorSeed->setText(tr2i18n("Generator seed:", nullptr));
        randomAllowSelfedges->setText(QString());
        label_GNPNodes->setText(tr2i18n("Nodes (n):", nullptr));
        label_GNPSelfEdges->setText(tr2i18n("Allow self-edges:", nullptr));
        label_GNPEdgeProbability->setText(tr2i18n("Edge Probability (p):", nullptr));
        label_GNPGeneratorSeed->setText(tr2i18n("Generator Seed:", nullptr));
        GNPAllowSelfedges->setText(QString());
        label_randomTreeNodes->setText(tr2i18n("Nodes:", nullptr));
        label_randomTreeGeneratorSeed->setText(tr2i18n("Generator Seed:", nullptr));
        label_numberNodes->setText(tr2i18n("Number of Nodes", nullptr));
        label_edgeProbability->setText(tr2i18n("Edge Probability", nullptr));
        label_dagGeneratorSeed->setText(tr2i18n("Generator Seed", nullptr));
        labe_pathNodes->setText(tr2i18n("Number of Nodes:", nullptr));
        label_completeNodes->setText(tr2i18n("Number of Nodes:", nullptr));
        label_completeBipartiteNodesLeft->setText(tr2i18n("Left Set Nodes:", nullptr));
        label_completeBipartiteNodesRight->setText(tr2i18n("Right Set Nodes:", nullptr));
#if QT_CONFIG(tooltip)
        edgeTypeSelector->setToolTip(tr2i18n("Select the edge type for connections of the generated graph.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        labelEdgeType->setToolTip(tr2i18n("The edge type to create the edges of the graph with", nullptr));
#endif // QT_CONFIG(tooltip)
        labelEdgeType->setText(tr2i18n("Edge type:", nullptr));
        labelGenerator->setText(tr2i18n("Graph generator:", nullptr));
#if QT_CONFIG(tooltip)
        nodeTypeSelector->setToolTip(tr2i18n("Select the node type for node elements of the generated graph.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class GenerateGraphWidget: public Ui_GenerateGraphWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERATEGRAPHWIDGET_H

