/****************************************************************************
** Meta object code from reading C++ file 'project.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../rocs-26.07.90/src/project/project.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'project.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ProjectE_t {};
} // unnamed namespace

template <> constexpr inline auto Project::qt_create_metaobjectdata<qt_meta_tag_ZN7ProjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Project",
        "codeDocumentAboutToBeAdded",
        "",
        "KTextEditor::Document*",
        "codeDocumentAdded",
        "codeDocumentAboutToBeRemoved",
        "codeDocumentRemoved",
        "activeCodeDocumentChanged",
        "index",
        "modifiedChanged",
        "graphDocumentAboutToBeAdded",
        "GraphTheory::GraphDocumentPtr",
        "graphDocumentAdded",
        "graphDocumentAboutToBeRemoved",
        "graphDocumentRemoved",
        "activeGraphDocumentChanged",
        "document",
        "setActiveCodeDocument",
        "setActiveGraphDocument"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'codeDocumentAboutToBeAdded'
        QtMocHelpers::SignalData<void(KTextEditor::Document *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'codeDocumentAdded'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'codeDocumentAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'codeDocumentRemoved'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeCodeDocumentChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphDocumentAboutToBeAdded'
        QtMocHelpers::SignalData<void(GraphTheory::GraphDocumentPtr, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'graphDocumentAdded'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphDocumentAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'graphDocumentRemoved'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeGraphDocumentChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'activeGraphDocumentChanged'
        QtMocHelpers::SignalData<void(GraphTheory::GraphDocumentPtr)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 16 },
        }}),
        // Slot 'setActiveCodeDocument'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setActiveGraphDocument'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Project, qt_meta_tag_ZN7ProjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Project::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ProjectE_t>.metaTypes,
    nullptr
} };

void Project::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Project *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->codeDocumentAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->codeDocumentAdded(); break;
        case 2: _t->codeDocumentAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->codeDocumentRemoved(); break;
        case 4: _t->activeCodeDocumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->modifiedChanged(); break;
        case 6: _t->graphDocumentAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<GraphTheory::GraphDocumentPtr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->graphDocumentAdded(); break;
        case 8: _t->graphDocumentAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->graphDocumentRemoved(); break;
        case 10: _t->activeGraphDocumentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->activeGraphDocumentChanged((*reinterpret_cast<std::add_pointer_t<GraphTheory::GraphDocumentPtr>>(_a[1]))); break;
        case 12: _t->setActiveCodeDocument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->setActiveGraphDocument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Project::*)(KTextEditor::Document * , int )>(_a, &Project::codeDocumentAboutToBeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::codeDocumentAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(int , int )>(_a, &Project::codeDocumentAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::codeDocumentRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(int )>(_a, &Project::activeCodeDocumentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::modifiedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(GraphTheory::GraphDocumentPtr , int )>(_a, &Project::graphDocumentAboutToBeAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::graphDocumentAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(int , int )>(_a, &Project::graphDocumentAboutToBeRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::graphDocumentRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(int )>(_a, &Project::activeGraphDocumentChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(GraphTheory::GraphDocumentPtr )>(_a, &Project::activeGraphDocumentChanged, 11))
            return;
    }
}

const QMetaObject *Project::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Project::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Project::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Project::codeDocumentAboutToBeAdded(KTextEditor::Document * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Project::codeDocumentAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Project::codeDocumentAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Project::codeDocumentRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Project::activeCodeDocumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Project::modifiedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Project::graphDocumentAboutToBeAdded(GraphTheory::GraphDocumentPtr _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Project::graphDocumentAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Project::graphDocumentAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Project::graphDocumentRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Project::activeGraphDocumentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Project::activeGraphDocumentChanged(GraphTheory::GraphDocumentPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
