/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<edgeitem.h>)
#  include <edgeitem.h>
#endif
#if __has_include(<edgemodel.h>)
#  include <edgemodel.h>
#endif
#if __has_include(<edgepropertymodel.h>)
#  include <edgepropertymodel.h>
#endif
#if __has_include(<edgeproxy.h>)
#  include <edgeproxy.h>
#endif
#if __has_include(<edgetypemodel.h>)
#  include <edgetypemodel.h>
#endif
#if __has_include(<edgetypepropertymodel.h>)
#  include <edgetypepropertymodel.h>
#endif
#if __has_include(<graph.h>)
#  include <graph.h>
#endif
#if __has_include(<nodeitem.h>)
#  include <nodeitem.h>
#endif
#if __has_include(<nodemodel.h>)
#  include <nodemodel.h>
#endif
#if __has_include(<nodepropertymodel.h>)
#  include <nodepropertymodel.h>
#endif
#if __has_include(<nodeproxy.h>)
#  include <nodeproxy.h>
#endif
#if __has_include(<nodetypemodel.h>)
#  include <nodetypemodel.h>
#endif
#if __has_include(<nodetypepropertymodel.h>)
#  include <nodetypepropertymodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_rocs()
{
    qmlRegisterModule("org.kde.rocs", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<GraphTheory::EdgeItem>("org.kde.rocs", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::EdgeModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::EdgePropertyModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::EdgeProxy>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::EdgeTypeModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::EdgeTypePropertyModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::Graph>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodeItem>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodeModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodePropertyModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodeProxy>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodeTypeModel>("org.kde.rocs", 254);
    qmlRegisterTypesAndRevisions<GraphTheory::NodeTypePropertyModel>("org.kde.rocs", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.rocs", 254, 254);
}

static const QQmlModuleRegistration orgkderocsRegistration("org.kde.rocs", qml_register_types_org_kde_rocs);
